# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #

from enum import Enum

from .api import API
from .base_object import BaseObject
from .errors import *
from .functions import *
from .types import *

BaseObject._all = {
    'accountTtl': AccountTtl,
    'address': Address,
    'animatedChatPhoto': AnimatedChatPhoto,
    'animation': Animation,
    'animations': Animations,
    'audio': Audio,
    'authenticationCodeInfo': AuthenticationCodeInfo,
    'authenticationCodeType': AuthenticationCodeType,
    'authenticationCodeTypeCall': AuthenticationCodeTypeCall,
    'authenticationCodeTypeFlashCall': AuthenticationCodeTypeFlashCall,
    'authenticationCodeTypeSms': AuthenticationCodeTypeSms,
    'authenticationCodeTypeTelegramMessage': AuthenticationCodeTypeTelegramMessage,
    'authorizationState': AuthorizationState,
    'authorizationStateClosed': AuthorizationStateClosed,
    'authorizationStateClosing': AuthorizationStateClosing,
    'authorizationStateLoggingOut': AuthorizationStateLoggingOut,
    'authorizationStateReady': AuthorizationStateReady,
    'authorizationStateWaitCode': AuthorizationStateWaitCode,
    'authorizationStateWaitEncryptionKey': AuthorizationStateWaitEncryptionKey,
    'authorizationStateWaitOtherDeviceConfirmation': AuthorizationStateWaitOtherDeviceConfirmation,
    'authorizationStateWaitPassword': AuthorizationStateWaitPassword,
    'authorizationStateWaitPhoneNumber': AuthorizationStateWaitPhoneNumber,
    'authorizationStateWaitRegistration': AuthorizationStateWaitRegistration,
    'authorizationStateWaitTdlibParameters': AuthorizationStateWaitTdlibParameters,
    'autoDownloadSettings': AutoDownloadSettings,
    'autoDownloadSettingsPresets': AutoDownloadSettingsPresets,
    'background': Background,
    'backgroundFill': BackgroundFill,
    'backgroundFillGradient': BackgroundFillGradient,
    'backgroundFillSolid': BackgroundFillSolid,
    'backgroundType': BackgroundType,
    'backgroundTypeFill': BackgroundTypeFill,
    'backgroundTypePattern': BackgroundTypePattern,
    'backgroundTypeWallpaper': BackgroundTypeWallpaper,
    'backgrounds': Backgrounds,
    'bankCardActionOpenUrl': BankCardActionOpenUrl,
    'bankCardInfo': BankCardInfo,
    'basicGroup': BasicGroup,
    'basicGroupFullInfo': BasicGroupFullInfo,
    'botCommand': BotCommand,
    'botInfo': BotInfo,
    'call': Call,
    'callDiscardReason': CallDiscardReason,
    'callDiscardReasonDeclined': CallDiscardReasonDeclined,
    'callDiscardReasonDisconnected': CallDiscardReasonDisconnected,
    'callDiscardReasonEmpty': CallDiscardReasonEmpty,
    'callDiscardReasonHungUp': CallDiscardReasonHungUp,
    'callDiscardReasonMissed': CallDiscardReasonMissed,
    'callId': CallId,
    'callProblem': CallProblem,
    'callProblemDistortedSpeech': CallProblemDistortedSpeech,
    'callProblemDistortedVideo': CallProblemDistortedVideo,
    'callProblemDropped': CallProblemDropped,
    'callProblemEcho': CallProblemEcho,
    'callProblemInterruptions': CallProblemInterruptions,
    'callProblemNoise': CallProblemNoise,
    'callProblemPixelatedVideo': CallProblemPixelatedVideo,
    'callProblemSilentLocal': CallProblemSilentLocal,
    'callProblemSilentRemote': CallProblemSilentRemote,
    'callProtocol': CallProtocol,
    'callServer': CallServer,
    'callServerType': CallServerType,
    'callServerTypeTelegramReflector': CallServerTypeTelegramReflector,
    'callServerTypeWebrtc': CallServerTypeWebrtc,
    'callState': CallState,
    'callStateDiscarded': CallStateDiscarded,
    'callStateError': CallStateError,
    'callStateExchangingKeys': CallStateExchangingKeys,
    'callStateHangingUp': CallStateHangingUp,
    'callStatePending': CallStatePending,
    'callStateReady': CallStateReady,
    'callbackQueryAnswer': CallbackQueryAnswer,
    'callbackQueryPayload': CallbackQueryPayload,
    'callbackQueryPayloadData': CallbackQueryPayloadData,
    'callbackQueryPayloadDataWithPassword': CallbackQueryPayloadDataWithPassword,
    'callbackQueryPayloadGame': CallbackQueryPayloadGame,
    'canTransferOwnershipResult': CanTransferOwnershipResult,
    'canTransferOwnershipResultOk': CanTransferOwnershipResultOk,
    'canTransferOwnershipResultPasswordNeeded': CanTransferOwnershipResultPasswordNeeded,
    'canTransferOwnershipResultPasswordTooFresh': CanTransferOwnershipResultPasswordTooFresh,
    'canTransferOwnershipResultSessionTooFresh': CanTransferOwnershipResultSessionTooFresh,
    'chat': Chat,
    'chatAction': ChatAction,
    'chatActionCancel': ChatActionCancel,
    'chatActionChoosingContact': ChatActionChoosingContact,
    'chatActionChoosingLocation': ChatActionChoosingLocation,
    'chatActionRecordingVideo': ChatActionRecordingVideo,
    'chatActionRecordingVideoNote': ChatActionRecordingVideoNote,
    'chatActionRecordingVoiceNote': ChatActionRecordingVoiceNote,
    'chatActionStartPlayingGame': ChatActionStartPlayingGame,
    'chatActionTyping': ChatActionTyping,
    'chatActionUploadingDocument': ChatActionUploadingDocument,
    'chatActionUploadingPhoto': ChatActionUploadingPhoto,
    'chatActionUploadingVideo': ChatActionUploadingVideo,
    'chatActionUploadingVideoNote': ChatActionUploadingVideoNote,
    'chatActionUploadingVoiceNote': ChatActionUploadingVoiceNote,
    'chatActionBar': ChatActionBar,
    'chatActionBarAddContact': ChatActionBarAddContact,
    'chatActionBarInviteMembers': ChatActionBarInviteMembers,
    'chatActionBarReportAddBlock': ChatActionBarReportAddBlock,
    'chatActionBarReportSpam': ChatActionBarReportSpam,
    'chatActionBarReportUnrelatedLocation': ChatActionBarReportUnrelatedLocation,
    'chatActionBarSharePhoneNumber': ChatActionBarSharePhoneNumber,
    'chatAdministrator': ChatAdministrator,
    'chatAdministrators': ChatAdministrators,
    'chatEvent': ChatEvent,
    'chatEventAction': ChatEventAction,
    'chatEventDescriptionChanged': ChatEventDescriptionChanged,
    'chatEventInviteLinkDeleted': ChatEventInviteLinkDeleted,
    'chatEventInviteLinkEdited': ChatEventInviteLinkEdited,
    'chatEventInviteLinkRevoked': ChatEventInviteLinkRevoked,
    'chatEventInvitesToggled': ChatEventInvitesToggled,
    'chatEventIsAllHistoryAvailableToggled': ChatEventIsAllHistoryAvailableToggled,
    'chatEventLinkedChatChanged': ChatEventLinkedChatChanged,
    'chatEventLocationChanged': ChatEventLocationChanged,
    'chatEventMemberInvited': ChatEventMemberInvited,
    'chatEventMemberJoined': ChatEventMemberJoined,
    'chatEventMemberJoinedByInviteLink': ChatEventMemberJoinedByInviteLink,
    'chatEventMemberLeft': ChatEventMemberLeft,
    'chatEventMemberPromoted': ChatEventMemberPromoted,
    'chatEventMemberRestricted': ChatEventMemberRestricted,
    'chatEventMessageDeleted': ChatEventMessageDeleted,
    'chatEventMessageEdited': ChatEventMessageEdited,
    'chatEventMessagePinned': ChatEventMessagePinned,
    'chatEventMessageTtlSettingChanged': ChatEventMessageTtlSettingChanged,
    'chatEventMessageUnpinned': ChatEventMessageUnpinned,
    'chatEventPermissionsChanged': ChatEventPermissionsChanged,
    'chatEventPhotoChanged': ChatEventPhotoChanged,
    'chatEventPollStopped': ChatEventPollStopped,
    'chatEventSignMessagesToggled': ChatEventSignMessagesToggled,
    'chatEventSlowModeDelayChanged': ChatEventSlowModeDelayChanged,
    'chatEventStickerSetChanged': ChatEventStickerSetChanged,
    'chatEventTitleChanged': ChatEventTitleChanged,
    'chatEventUsernameChanged': ChatEventUsernameChanged,
    'chatEventVoiceChatCreated': ChatEventVoiceChatCreated,
    'chatEventVoiceChatDiscarded': ChatEventVoiceChatDiscarded,
    'chatEventVoiceChatMuteNewParticipantsToggled': ChatEventVoiceChatMuteNewParticipantsToggled,
    'chatEventVoiceChatParticipantIsMutedToggled': ChatEventVoiceChatParticipantIsMutedToggled,
    'chatEventVoiceChatParticipantVolumeLevelChanged': ChatEventVoiceChatParticipantVolumeLevelChanged,
    'chatEventLogFilters': ChatEventLogFilters,
    'chatEvents': ChatEvents,
    'chatFilter': ChatFilter,
    'chatFilterInfo': ChatFilterInfo,
    'chatInviteLink': ChatInviteLink,
    'chatInviteLinkCount': ChatInviteLinkCount,
    'chatInviteLinkCounts': ChatInviteLinkCounts,
    'chatInviteLinkInfo': ChatInviteLinkInfo,
    'chatInviteLinkMember': ChatInviteLinkMember,
    'chatInviteLinkMembers': ChatInviteLinkMembers,
    'chatInviteLinks': ChatInviteLinks,
    'chatList': ChatList,
    'chatListArchive': ChatListArchive,
    'chatListFilter': ChatListFilter,
    'chatListMain': ChatListMain,
    'chatLists': ChatLists,
    'chatLocation': ChatLocation,
    'chatMember': ChatMember,
    'chatMemberStatus': ChatMemberStatus,
    'chatMemberStatusAdministrator': ChatMemberStatusAdministrator,
    'chatMemberStatusBanned': ChatMemberStatusBanned,
    'chatMemberStatusCreator': ChatMemberStatusCreator,
    'chatMemberStatusLeft': ChatMemberStatusLeft,
    'chatMemberStatusMember': ChatMemberStatusMember,
    'chatMemberStatusRestricted': ChatMemberStatusRestricted,
    'chatMembers': ChatMembers,
    'chatMembersFilter': ChatMembersFilter,
    'chatMembersFilterAdministrators': ChatMembersFilterAdministrators,
    'chatMembersFilterBanned': ChatMembersFilterBanned,
    'chatMembersFilterBots': ChatMembersFilterBots,
    'chatMembersFilterContacts': ChatMembersFilterContacts,
    'chatMembersFilterMembers': ChatMembersFilterMembers,
    'chatMembersFilterMention': ChatMembersFilterMention,
    'chatMembersFilterRestricted': ChatMembersFilterRestricted,
    'chatNearby': ChatNearby,
    'chatNotificationSettings': ChatNotificationSettings,
    'chatPermissions': ChatPermissions,
    'chatPhoto': ChatPhoto,
    'chatPhotoInfo': ChatPhotoInfo,
    'chatPhotos': ChatPhotos,
    'chatPosition': ChatPosition,
    'chatReportReason': ChatReportReason,
    'chatReportReasonChildAbuse': ChatReportReasonChildAbuse,
    'chatReportReasonCopyright': ChatReportReasonCopyright,
    'chatReportReasonCustom': ChatReportReasonCustom,
    'chatReportReasonFake': ChatReportReasonFake,
    'chatReportReasonPornography': ChatReportReasonPornography,
    'chatReportReasonSpam': ChatReportReasonSpam,
    'chatReportReasonUnrelatedLocation': ChatReportReasonUnrelatedLocation,
    'chatReportReasonViolence': ChatReportReasonViolence,
    'chatSource': ChatSource,
    'chatSourceMtprotoProxy': ChatSourceMtprotoProxy,
    'chatSourcePublicServiceAnnouncement': ChatSourcePublicServiceAnnouncement,
    'chatStatistics': ChatStatistics,
    'chatStatisticsChannel': ChatStatisticsChannel,
    'chatStatisticsSupergroup': ChatStatisticsSupergroup,
    'chatStatisticsAdministratorActionsInfo': ChatStatisticsAdministratorActionsInfo,
    'chatStatisticsInviterInfo': ChatStatisticsInviterInfo,
    'chatStatisticsMessageInteractionInfo': ChatStatisticsMessageInteractionInfo,
    'chatStatisticsMessageSenderInfo': ChatStatisticsMessageSenderInfo,
    'chatType': ChatType,
    'chatTypeBasicGroup': ChatTypeBasicGroup,
    'chatTypePrivate': ChatTypePrivate,
    'chatTypeSecret': ChatTypeSecret,
    'chatTypeSupergroup': ChatTypeSupergroup,
    'chats': Chats,
    'chatsNearby': ChatsNearby,
    'checkChatUsernameResult': CheckChatUsernameResult,
    'checkChatUsernameResultOk': CheckChatUsernameResultOk,
    'checkChatUsernameResultPublicChatsTooMuch': CheckChatUsernameResultPublicChatsTooMuch,
    'checkChatUsernameResultPublicGroupsUnavailable': CheckChatUsernameResultPublicGroupsUnavailable,
    'checkChatUsernameResultUsernameInvalid': CheckChatUsernameResultUsernameInvalid,
    'checkChatUsernameResultUsernameOccupied': CheckChatUsernameResultUsernameOccupied,
    'closedVectorPath': ClosedVectorPath,
    'connectedWebsite': ConnectedWebsite,
    'connectedWebsites': ConnectedWebsites,
    'connectionState': ConnectionState,
    'connectionStateConnecting': ConnectionStateConnecting,
    'connectionStateConnectingToProxy': ConnectionStateConnectingToProxy,
    'connectionStateReady': ConnectionStateReady,
    'connectionStateUpdating': ConnectionStateUpdating,
    'connectionStateWaitingForNetwork': ConnectionStateWaitingForNetwork,
    'contact': Contact,
    'count': Count,
    'countries': Countries,
    'countryInfo': CountryInfo,
    'customRequestResult': CustomRequestResult,
    'databaseStatistics': DatabaseStatistics,
    'date': Date,
    'dateRange': DateRange,
    'datedFile': DatedFile,
    'deepLinkInfo': DeepLinkInfo,
    'deviceToken': DeviceToken,
    'deviceTokenApplePush': DeviceTokenApplePush,
    'deviceTokenApplePushVoIP': DeviceTokenApplePushVoIP,
    'deviceTokenBlackBerryPush': DeviceTokenBlackBerryPush,
    'deviceTokenFirebaseCloudMessaging': DeviceTokenFirebaseCloudMessaging,
    'deviceTokenMicrosoftPush': DeviceTokenMicrosoftPush,
    'deviceTokenMicrosoftPushVoIP': DeviceTokenMicrosoftPushVoIP,
    'deviceTokenSimplePush': DeviceTokenSimplePush,
    'deviceTokenTizenPush': DeviceTokenTizenPush,
    'deviceTokenUbuntuPush': DeviceTokenUbuntuPush,
    'deviceTokenWebPush': DeviceTokenWebPush,
    'deviceTokenWindowsPush': DeviceTokenWindowsPush,
    'diceStickers': DiceStickers,
    'diceStickersRegular': DiceStickersRegular,
    'diceStickersSlotMachine': DiceStickersSlotMachine,
    'document': Document,
    'draftMessage': DraftMessage,
    'emailAddressAuthenticationCodeInfo': EmailAddressAuthenticationCodeInfo,
    'emojis': Emojis,
    'encryptedCredentials': EncryptedCredentials,
    'encryptedPassportElement': EncryptedPassportElement,
    'error': Error,
    'file': File,
    'filePart': FilePart,
    'fileType': FileType,
    'fileTypeAnimation': FileTypeAnimation,
    'fileTypeAudio': FileTypeAudio,
    'fileTypeDocument': FileTypeDocument,
    'fileTypeNone': FileTypeNone,
    'fileTypePhoto': FileTypePhoto,
    'fileTypeProfilePhoto': FileTypeProfilePhoto,
    'fileTypeSecret': FileTypeSecret,
    'fileTypeSecretThumbnail': FileTypeSecretThumbnail,
    'fileTypeSecure': FileTypeSecure,
    'fileTypeSticker': FileTypeSticker,
    'fileTypeThumbnail': FileTypeThumbnail,
    'fileTypeUnknown': FileTypeUnknown,
    'fileTypeVideo': FileTypeVideo,
    'fileTypeVideoNote': FileTypeVideoNote,
    'fileTypeVoiceNote': FileTypeVoiceNote,
    'fileTypeWallpaper': FileTypeWallpaper,
    'formattedText': FormattedText,
    'foundMessages': FoundMessages,
    'game': Game,
    'gameHighScore': GameHighScore,
    'gameHighScores': GameHighScores,
    'groupCall': GroupCall,
    'groupCallId': GroupCallId,
    'groupCallJoinResponse': GroupCallJoinResponse,
    'groupCallJoinResponseStream': GroupCallJoinResponseStream,
    'groupCallJoinResponseWebrtc': GroupCallJoinResponseWebrtc,
    'groupCallJoinResponseCandidate': GroupCallJoinResponseCandidate,
    'groupCallParticipant': GroupCallParticipant,
    'groupCallPayload': GroupCallPayload,
    'groupCallPayloadFingerprint': GroupCallPayloadFingerprint,
    'groupCallRecentSpeaker': GroupCallRecentSpeaker,
    'hashtags': Hashtags,
    'httpUrl': HttpUrl,
    'identityDocument': IdentityDocument,
    'importedContacts': ImportedContacts,
    'inlineKeyboardButton': InlineKeyboardButton,
    'inlineKeyboardButtonType': InlineKeyboardButtonType,
    'inlineKeyboardButtonTypeBuy': InlineKeyboardButtonTypeBuy,
    'inlineKeyboardButtonTypeCallback': InlineKeyboardButtonTypeCallback,
    'inlineKeyboardButtonTypeCallbackGame': InlineKeyboardButtonTypeCallbackGame,
    'inlineKeyboardButtonTypeCallbackWithPassword': InlineKeyboardButtonTypeCallbackWithPassword,
    'inlineKeyboardButtonTypeLoginUrl': InlineKeyboardButtonTypeLoginUrl,
    'inlineKeyboardButtonTypeSwitchInline': InlineKeyboardButtonTypeSwitchInline,
    'inlineKeyboardButtonTypeUrl': InlineKeyboardButtonTypeUrl,
    'inlineQueryResult': InlineQueryResult,
    'inlineQueryResultAnimation': InlineQueryResultAnimation,
    'inlineQueryResultArticle': InlineQueryResultArticle,
    'inlineQueryResultAudio': InlineQueryResultAudio,
    'inlineQueryResultContact': InlineQueryResultContact,
    'inlineQueryResultDocument': InlineQueryResultDocument,
    'inlineQueryResultGame': InlineQueryResultGame,
    'inlineQueryResultLocation': InlineQueryResultLocation,
    'inlineQueryResultPhoto': InlineQueryResultPhoto,
    'inlineQueryResultSticker': InlineQueryResultSticker,
    'inlineQueryResultVenue': InlineQueryResultVenue,
    'inlineQueryResultVideo': InlineQueryResultVideo,
    'inlineQueryResultVoiceNote': InlineQueryResultVoiceNote,
    'inlineQueryResults': InlineQueryResults,
    'inputBackground': InputBackground,
    'inputBackgroundLocal': InputBackgroundLocal,
    'inputBackgroundRemote': InputBackgroundRemote,
    'inputChatPhoto': InputChatPhoto,
    'inputChatPhotoAnimation': InputChatPhotoAnimation,
    'inputChatPhotoPrevious': InputChatPhotoPrevious,
    'inputChatPhotoStatic': InputChatPhotoStatic,
    'inputCredentials': InputCredentials,
    'inputCredentialsApplePay': InputCredentialsApplePay,
    'inputCredentialsGooglePay': InputCredentialsGooglePay,
    'inputCredentialsNew': InputCredentialsNew,
    'inputCredentialsSaved': InputCredentialsSaved,
    'inputFile': InputFile,
    'inputFileGenerated': InputFileGenerated,
    'inputFileId': InputFileId,
    'inputFileLocal': InputFileLocal,
    'inputFileRemote': InputFileRemote,
    'inputIdentityDocument': InputIdentityDocument,
    'inputInlineQueryResult': InputInlineQueryResult,
    'inputInlineQueryResultAnimation': InputInlineQueryResultAnimation,
    'inputInlineQueryResultArticle': InputInlineQueryResultArticle,
    'inputInlineQueryResultAudio': InputInlineQueryResultAudio,
    'inputInlineQueryResultContact': InputInlineQueryResultContact,
    'inputInlineQueryResultDocument': InputInlineQueryResultDocument,
    'inputInlineQueryResultGame': InputInlineQueryResultGame,
    'inputInlineQueryResultLocation': InputInlineQueryResultLocation,
    'inputInlineQueryResultPhoto': InputInlineQueryResultPhoto,
    'inputInlineQueryResultSticker': InputInlineQueryResultSticker,
    'inputInlineQueryResultVenue': InputInlineQueryResultVenue,
    'inputInlineQueryResultVideo': InputInlineQueryResultVideo,
    'inputInlineQueryResultVoiceNote': InputInlineQueryResultVoiceNote,
    'inputMessageContent': InputMessageContent,
    'inputMessageAnimation': InputMessageAnimation,
    'inputMessageAudio': InputMessageAudio,
    'inputMessageContact': InputMessageContact,
    'inputMessageDice': InputMessageDice,
    'inputMessageDocument': InputMessageDocument,
    'inputMessageForwarded': InputMessageForwarded,
    'inputMessageGame': InputMessageGame,
    'inputMessageInvoice': InputMessageInvoice,
    'inputMessageLocation': InputMessageLocation,
    'inputMessagePhoto': InputMessagePhoto,
    'inputMessagePoll': InputMessagePoll,
    'inputMessageSticker': InputMessageSticker,
    'inputMessageText': InputMessageText,
    'inputMessageVenue': InputMessageVenue,
    'inputMessageVideo': InputMessageVideo,
    'inputMessageVideoNote': InputMessageVideoNote,
    'inputMessageVoiceNote': InputMessageVoiceNote,
    'inputPassportElement': InputPassportElement,
    'inputPassportElementAddress': InputPassportElementAddress,
    'inputPassportElementBankStatement': InputPassportElementBankStatement,
    'inputPassportElementDriverLicense': InputPassportElementDriverLicense,
    'inputPassportElementEmailAddress': InputPassportElementEmailAddress,
    'inputPassportElementIdentityCard': InputPassportElementIdentityCard,
    'inputPassportElementInternalPassport': InputPassportElementInternalPassport,
    'inputPassportElementPassport': InputPassportElementPassport,
    'inputPassportElementPassportRegistration': InputPassportElementPassportRegistration,
    'inputPassportElementPersonalDetails': InputPassportElementPersonalDetails,
    'inputPassportElementPhoneNumber': InputPassportElementPhoneNumber,
    'inputPassportElementRentalAgreement': InputPassportElementRentalAgreement,
    'inputPassportElementTemporaryRegistration': InputPassportElementTemporaryRegistration,
    'inputPassportElementUtilityBill': InputPassportElementUtilityBill,
    'inputPassportElementError': InputPassportElementError,
    'inputPassportElementErrorSource': InputPassportElementErrorSource,
    'inputPassportElementErrorSourceDataField': InputPassportElementErrorSourceDataField,
    'inputPassportElementErrorSourceFile': InputPassportElementErrorSourceFile,
    'inputPassportElementErrorSourceFiles': InputPassportElementErrorSourceFiles,
    'inputPassportElementErrorSourceFrontSide': InputPassportElementErrorSourceFrontSide,
    'inputPassportElementErrorSourceReverseSide': InputPassportElementErrorSourceReverseSide,
    'inputPassportElementErrorSourceSelfie': InputPassportElementErrorSourceSelfie,
    'inputPassportElementErrorSourceTranslationFile': InputPassportElementErrorSourceTranslationFile,
    'inputPassportElementErrorSourceTranslationFiles': InputPassportElementErrorSourceTranslationFiles,
    'inputPassportElementErrorSourceUnspecified': InputPassportElementErrorSourceUnspecified,
    'inputPersonalDocument': InputPersonalDocument,
    'inputSticker': InputSticker,
    'inputStickerAnimated': InputStickerAnimated,
    'inputStickerStatic': InputStickerStatic,
    'inputThumbnail': InputThumbnail,
    'invoice': Invoice,
    'jsonValue': JsonValue,
    'jsonValueArray': JsonValueArray,
    'jsonValueBoolean': JsonValueBoolean,
    'jsonValueNull': JsonValueNull,
    'jsonValueNumber': JsonValueNumber,
    'jsonValueObject': JsonValueObject,
    'jsonValueString': JsonValueString,
    'keyboardButton': KeyboardButton,
    'keyboardButtonType': KeyboardButtonType,
    'keyboardButtonTypeRequestLocation': KeyboardButtonTypeRequestLocation,
    'keyboardButtonTypeRequestPhoneNumber': KeyboardButtonTypeRequestPhoneNumber,
    'keyboardButtonTypeRequestPoll': KeyboardButtonTypeRequestPoll,
    'keyboardButtonTypeText': KeyboardButtonTypeText,
    'labeledPricePart': LabeledPricePart,
    'languagePackInfo': LanguagePackInfo,
    'languagePackString': LanguagePackString,
    'languagePackStringValue': LanguagePackStringValue,
    'languagePackStringValueDeleted': LanguagePackStringValueDeleted,
    'languagePackStringValueOrdinary': LanguagePackStringValueOrdinary,
    'languagePackStringValuePluralized': LanguagePackStringValuePluralized,
    'languagePackStrings': LanguagePackStrings,
    'localFile': LocalFile,
    'localizationTargetInfo': LocalizationTargetInfo,
    'location': Location,
    'logStream': LogStream,
    'logStreamDefault': LogStreamDefault,
    'logStreamEmpty': LogStreamEmpty,
    'logStreamFile': LogStreamFile,
    'logTags': LogTags,
    'logVerbosityLevel': LogVerbosityLevel,
    'loginUrlInfo': LoginUrlInfo,
    'loginUrlInfoOpen': LoginUrlInfoOpen,
    'loginUrlInfoRequestConfirmation': LoginUrlInfoRequestConfirmation,
    'maskPoint': MaskPoint,
    'maskPointChin': MaskPointChin,
    'maskPointEyes': MaskPointEyes,
    'maskPointForehead': MaskPointForehead,
    'maskPointMouth': MaskPointMouth,
    'maskPosition': MaskPosition,
    'message': Message,
    'messageContent': MessageContent,
    'messageAnimation': MessageAnimation,
    'messageAudio': MessageAudio,
    'messageBasicGroupChatCreate': MessageBasicGroupChatCreate,
    'messageCall': MessageCall,
    'messageChatAddMembers': MessageChatAddMembers,
    'messageChatChangePhoto': MessageChatChangePhoto,
    'messageChatChangeTitle': MessageChatChangeTitle,
    'messageChatDeleteMember': MessageChatDeleteMember,
    'messageChatDeletePhoto': MessageChatDeletePhoto,
    'messageChatJoinByLink': MessageChatJoinByLink,
    'messageChatSetTtl': MessageChatSetTtl,
    'messageChatUpgradeFrom': MessageChatUpgradeFrom,
    'messageChatUpgradeTo': MessageChatUpgradeTo,
    'messageContact': MessageContact,
    'messageContactRegistered': MessageContactRegistered,
    'messageCustomServiceAction': MessageCustomServiceAction,
    'messageDice': MessageDice,
    'messageDocument': MessageDocument,
    'messageExpiredPhoto': MessageExpiredPhoto,
    'messageExpiredVideo': MessageExpiredVideo,
    'messageGame': MessageGame,
    'messageGameScore': MessageGameScore,
    'messageInviteVoiceChatParticipants': MessageInviteVoiceChatParticipants,
    'messageInvoice': MessageInvoice,
    'messageLocation': MessageLocation,
    'messagePassportDataReceived': MessagePassportDataReceived,
    'messagePassportDataSent': MessagePassportDataSent,
    'messagePaymentSuccessful': MessagePaymentSuccessful,
    'messagePaymentSuccessfulBot': MessagePaymentSuccessfulBot,
    'messagePhoto': MessagePhoto,
    'messagePinMessage': MessagePinMessage,
    'messagePoll': MessagePoll,
    'messageProximityAlertTriggered': MessageProximityAlertTriggered,
    'messageScreenshotTaken': MessageScreenshotTaken,
    'messageSticker': MessageSticker,
    'messageSupergroupChatCreate': MessageSupergroupChatCreate,
    'messageText': MessageText,
    'messageUnsupported': MessageUnsupported,
    'messageVenue': MessageVenue,
    'messageVideo': MessageVideo,
    'messageVideoNote': MessageVideoNote,
    'messageVoiceChatEnded': MessageVoiceChatEnded,
    'messageVoiceChatStarted': MessageVoiceChatStarted,
    'messageVoiceNote': MessageVoiceNote,
    'messageWebsiteConnected': MessageWebsiteConnected,
    'messageCopyOptions': MessageCopyOptions,
    'messageFileType': MessageFileType,
    'messageFileTypeGroup': MessageFileTypeGroup,
    'messageFileTypePrivate': MessageFileTypePrivate,
    'messageFileTypeUnknown': MessageFileTypeUnknown,
    'messageForwardInfo': MessageForwardInfo,
    'messageForwardOrigin': MessageForwardOrigin,
    'messageForwardOriginChannel': MessageForwardOriginChannel,
    'messageForwardOriginChat': MessageForwardOriginChat,
    'messageForwardOriginHiddenUser': MessageForwardOriginHiddenUser,
    'messageForwardOriginMessageImport': MessageForwardOriginMessageImport,
    'messageForwardOriginUser': MessageForwardOriginUser,
    'messageInteractionInfo': MessageInteractionInfo,
    'messageLink': MessageLink,
    'messageLinkInfo': MessageLinkInfo,
    'messageReplyInfo': MessageReplyInfo,
    'messageSchedulingState': MessageSchedulingState,
    'messageSchedulingStateSendAtDate': MessageSchedulingStateSendAtDate,
    'messageSchedulingStateSendWhenOnline': MessageSchedulingStateSendWhenOnline,
    'messageSendOptions': MessageSendOptions,
    'messageSender': MessageSender,
    'messageSenderChat': MessageSenderChat,
    'messageSenderUser': MessageSenderUser,
    'messageSenders': MessageSenders,
    'messageSendingState': MessageSendingState,
    'messageSendingStateFailed': MessageSendingStateFailed,
    'messageSendingStatePending': MessageSendingStatePending,
    'messageStatistics': MessageStatistics,
    'messageThreadInfo': MessageThreadInfo,
    'messages': Messages,
    'minithumbnail': Minithumbnail,
    'networkStatistics': NetworkStatistics,
    'networkStatisticsEntry': NetworkStatisticsEntry,
    'networkStatisticsEntryCall': NetworkStatisticsEntryCall,
    'networkStatisticsEntryFile': NetworkStatisticsEntryFile,
    'networkType': NetworkType,
    'networkTypeMobile': NetworkTypeMobile,
    'networkTypeMobileRoaming': NetworkTypeMobileRoaming,
    'networkTypeNone': NetworkTypeNone,
    'networkTypeOther': NetworkTypeOther,
    'networkTypeWiFi': NetworkTypeWiFi,
    'notification': Notification,
    'notificationGroup': NotificationGroup,
    'notificationGroupType': NotificationGroupType,
    'notificationGroupTypeCalls': NotificationGroupTypeCalls,
    'notificationGroupTypeMentions': NotificationGroupTypeMentions,
    'notificationGroupTypeMessages': NotificationGroupTypeMessages,
    'notificationGroupTypeSecretChat': NotificationGroupTypeSecretChat,
    'notificationSettingsScope': NotificationSettingsScope,
    'notificationSettingsScopeChannelChats': NotificationSettingsScopeChannelChats,
    'notificationSettingsScopeGroupChats': NotificationSettingsScopeGroupChats,
    'notificationSettingsScopePrivateChats': NotificationSettingsScopePrivateChats,
    'notificationType': NotificationType,
    'notificationTypeNewCall': NotificationTypeNewCall,
    'notificationTypeNewMessage': NotificationTypeNewMessage,
    'notificationTypeNewPushMessage': NotificationTypeNewPushMessage,
    'notificationTypeNewSecretChat': NotificationTypeNewSecretChat,
    'ok': Ok,
    'optionValue': OptionValue,
    'optionValueBoolean': OptionValueBoolean,
    'optionValueEmpty': OptionValueEmpty,
    'optionValueInteger': OptionValueInteger,
    'optionValueString': OptionValueString,
    'orderInfo': OrderInfo,
    'pageBlock': PageBlock,
    'pageBlockAnchor': PageBlockAnchor,
    'pageBlockAnimation': PageBlockAnimation,
    'pageBlockAudio': PageBlockAudio,
    'pageBlockAuthorDate': PageBlockAuthorDate,
    'pageBlockBlockQuote': PageBlockBlockQuote,
    'pageBlockChatLink': PageBlockChatLink,
    'pageBlockCollage': PageBlockCollage,
    'pageBlockCover': PageBlockCover,
    'pageBlockDetails': PageBlockDetails,
    'pageBlockDivider': PageBlockDivider,
    'pageBlockEmbedded': PageBlockEmbedded,
    'pageBlockEmbeddedPost': PageBlockEmbeddedPost,
    'pageBlockFooter': PageBlockFooter,
    'pageBlockHeader': PageBlockHeader,
    'pageBlockKicker': PageBlockKicker,
    'pageBlockList': PageBlockList,
    'pageBlockMap': PageBlockMap,
    'pageBlockParagraph': PageBlockParagraph,
    'pageBlockPhoto': PageBlockPhoto,
    'pageBlockPreformatted': PageBlockPreformatted,
    'pageBlockPullQuote': PageBlockPullQuote,
    'pageBlockRelatedArticles': PageBlockRelatedArticles,
    'pageBlockSlideshow': PageBlockSlideshow,
    'pageBlockSubheader': PageBlockSubheader,
    'pageBlockSubtitle': PageBlockSubtitle,
    'pageBlockTable': PageBlockTable,
    'pageBlockTitle': PageBlockTitle,
    'pageBlockVideo': PageBlockVideo,
    'pageBlockVoiceNote': PageBlockVoiceNote,
    'pageBlockCaption': PageBlockCaption,
    'pageBlockHorizontalAlignment': PageBlockHorizontalAlignment,
    'pageBlockHorizontalAlignmentCenter': PageBlockHorizontalAlignmentCenter,
    'pageBlockHorizontalAlignmentLeft': PageBlockHorizontalAlignmentLeft,
    'pageBlockHorizontalAlignmentRight': PageBlockHorizontalAlignmentRight,
    'pageBlockRelatedArticle': PageBlockRelatedArticle,
    'pageBlockTableCell': PageBlockTableCell,
    'pageBlockVerticalAlignment': PageBlockVerticalAlignment,
    'pageBlockVerticalAlignmentBottom': PageBlockVerticalAlignmentBottom,
    'pageBlockVerticalAlignmentMiddle': PageBlockVerticalAlignmentMiddle,
    'pageBlockVerticalAlignmentTop': PageBlockVerticalAlignmentTop,
    'passportAuthorizationForm': PassportAuthorizationForm,
    'passportElement': PassportElement,
    'passportElementAddress': PassportElementAddress,
    'passportElementBankStatement': PassportElementBankStatement,
    'passportElementDriverLicense': PassportElementDriverLicense,
    'passportElementEmailAddress': PassportElementEmailAddress,
    'passportElementIdentityCard': PassportElementIdentityCard,
    'passportElementInternalPassport': PassportElementInternalPassport,
    'passportElementPassport': PassportElementPassport,
    'passportElementPassportRegistration': PassportElementPassportRegistration,
    'passportElementPersonalDetails': PassportElementPersonalDetails,
    'passportElementPhoneNumber': PassportElementPhoneNumber,
    'passportElementRentalAgreement': PassportElementRentalAgreement,
    'passportElementTemporaryRegistration': PassportElementTemporaryRegistration,
    'passportElementUtilityBill': PassportElementUtilityBill,
    'passportElementError': PassportElementError,
    'passportElementErrorSource': PassportElementErrorSource,
    'passportElementErrorSourceDataField': PassportElementErrorSourceDataField,
    'passportElementErrorSourceFile': PassportElementErrorSourceFile,
    'passportElementErrorSourceFiles': PassportElementErrorSourceFiles,
    'passportElementErrorSourceFrontSide': PassportElementErrorSourceFrontSide,
    'passportElementErrorSourceReverseSide': PassportElementErrorSourceReverseSide,
    'passportElementErrorSourceSelfie': PassportElementErrorSourceSelfie,
    'passportElementErrorSourceTranslationFile': PassportElementErrorSourceTranslationFile,
    'passportElementErrorSourceTranslationFiles': PassportElementErrorSourceTranslationFiles,
    'passportElementErrorSourceUnspecified': PassportElementErrorSourceUnspecified,
    'passportElementType': PassportElementType,
    'passportElementTypeAddress': PassportElementTypeAddress,
    'passportElementTypeBankStatement': PassportElementTypeBankStatement,
    'passportElementTypeDriverLicense': PassportElementTypeDriverLicense,
    'passportElementTypeEmailAddress': PassportElementTypeEmailAddress,
    'passportElementTypeIdentityCard': PassportElementTypeIdentityCard,
    'passportElementTypeInternalPassport': PassportElementTypeInternalPassport,
    'passportElementTypePassport': PassportElementTypePassport,
    'passportElementTypePassportRegistration': PassportElementTypePassportRegistration,
    'passportElementTypePersonalDetails': PassportElementTypePersonalDetails,
    'passportElementTypePhoneNumber': PassportElementTypePhoneNumber,
    'passportElementTypeRentalAgreement': PassportElementTypeRentalAgreement,
    'passportElementTypeTemporaryRegistration': PassportElementTypeTemporaryRegistration,
    'passportElementTypeUtilityBill': PassportElementTypeUtilityBill,
    'passportElements': PassportElements,
    'passportElementsWithErrors': PassportElementsWithErrors,
    'passportRequiredElement': PassportRequiredElement,
    'passportSuitableElement': PassportSuitableElement,
    'passwordState': PasswordState,
    'paymentForm': PaymentForm,
    'paymentReceipt': PaymentReceipt,
    'paymentResult': PaymentResult,
    'paymentsProviderStripe': PaymentsProviderStripe,
    'personalDetails': PersonalDetails,
    'personalDocument': PersonalDocument,
    'phoneNumberAuthenticationSettings': PhoneNumberAuthenticationSettings,
    'phoneNumberInfo': PhoneNumberInfo,
    'photo': Photo,
    'photoSize': PhotoSize,
    'point': Point,
    'poll': Poll,
    'pollOption': PollOption,
    'pollType': PollType,
    'pollTypeQuiz': PollTypeQuiz,
    'pollTypeRegular': PollTypeRegular,
    'profilePhoto': ProfilePhoto,
    'proxies': Proxies,
    'proxy': Proxy,
    'proxyType': ProxyType,
    'proxyTypeHttp': ProxyTypeHttp,
    'proxyTypeMtproto': ProxyTypeMtproto,
    'proxyTypeSocks5': ProxyTypeSocks5,
    'publicChatType': PublicChatType,
    'publicChatTypeHasUsername': PublicChatTypeHasUsername,
    'publicChatTypeIsLocationBased': PublicChatTypeIsLocationBased,
    'pushMessageContent': PushMessageContent,
    'pushMessageContentAnimation': PushMessageContentAnimation,
    'pushMessageContentAudio': PushMessageContentAudio,
    'pushMessageContentBasicGroupChatCreate': PushMessageContentBasicGroupChatCreate,
    'pushMessageContentChatAddMembers': PushMessageContentChatAddMembers,
    'pushMessageContentChatChangePhoto': PushMessageContentChatChangePhoto,
    'pushMessageContentChatChangeTitle': PushMessageContentChatChangeTitle,
    'pushMessageContentChatDeleteMember': PushMessageContentChatDeleteMember,
    'pushMessageContentChatJoinByLink': PushMessageContentChatJoinByLink,
    'pushMessageContentContact': PushMessageContentContact,
    'pushMessageContentContactRegistered': PushMessageContentContactRegistered,
    'pushMessageContentDocument': PushMessageContentDocument,
    'pushMessageContentGame': PushMessageContentGame,
    'pushMessageContentGameScore': PushMessageContentGameScore,
    'pushMessageContentHidden': PushMessageContentHidden,
    'pushMessageContentInvoice': PushMessageContentInvoice,
    'pushMessageContentLocation': PushMessageContentLocation,
    'pushMessageContentMediaAlbum': PushMessageContentMediaAlbum,
    'pushMessageContentMessageForwards': PushMessageContentMessageForwards,
    'pushMessageContentPhoto': PushMessageContentPhoto,
    'pushMessageContentPoll': PushMessageContentPoll,
    'pushMessageContentScreenshotTaken': PushMessageContentScreenshotTaken,
    'pushMessageContentSticker': PushMessageContentSticker,
    'pushMessageContentText': PushMessageContentText,
    'pushMessageContentVideo': PushMessageContentVideo,
    'pushMessageContentVideoNote': PushMessageContentVideoNote,
    'pushMessageContentVoiceNote': PushMessageContentVoiceNote,
    'pushReceiverId': PushReceiverId,
    'recommendedChatFilter': RecommendedChatFilter,
    'recommendedChatFilters': RecommendedChatFilters,
    'recoveryEmailAddress': RecoveryEmailAddress,
    'remoteFile': RemoteFile,
    'replyMarkup': ReplyMarkup,
    'replyMarkupForceReply': ReplyMarkupForceReply,
    'replyMarkupInlineKeyboard': ReplyMarkupInlineKeyboard,
    'replyMarkupRemoveKeyboard': ReplyMarkupRemoveKeyboard,
    'replyMarkupShowKeyboard': ReplyMarkupShowKeyboard,
    'richText': RichText,
    'richTextAnchor': RichTextAnchor,
    'richTextAnchorLink': RichTextAnchorLink,
    'richTextBold': RichTextBold,
    'richTextEmailAddress': RichTextEmailAddress,
    'richTextFixed': RichTextFixed,
    'richTextIcon': RichTextIcon,
    'richTextItalic': RichTextItalic,
    'richTextMarked': RichTextMarked,
    'richTextPhoneNumber': RichTextPhoneNumber,
    'richTextPlain': RichTextPlain,
    'richTextReference': RichTextReference,
    'richTextStrikethrough': RichTextStrikethrough,
    'richTextSubscript': RichTextSubscript,
    'richTextSuperscript': RichTextSuperscript,
    'richTextUnderline': RichTextUnderline,
    'richTextUrl': RichTextUrl,
    'richTexts': RichTexts,
    'savedCredentials': SavedCredentials,
    'scopeNotificationSettings': ScopeNotificationSettings,
    'searchMessagesFilter': SearchMessagesFilter,
    'searchMessagesFilterAnimation': SearchMessagesFilterAnimation,
    'searchMessagesFilterAudio': SearchMessagesFilterAudio,
    'searchMessagesFilterCall': SearchMessagesFilterCall,
    'searchMessagesFilterChatPhoto': SearchMessagesFilterChatPhoto,
    'searchMessagesFilterDocument': SearchMessagesFilterDocument,
    'searchMessagesFilterEmpty': SearchMessagesFilterEmpty,
    'searchMessagesFilterFailedToSend': SearchMessagesFilterFailedToSend,
    'searchMessagesFilterMention': SearchMessagesFilterMention,
    'searchMessagesFilterMissedCall': SearchMessagesFilterMissedCall,
    'searchMessagesFilterPhoto': SearchMessagesFilterPhoto,
    'searchMessagesFilterPhotoAndVideo': SearchMessagesFilterPhotoAndVideo,
    'searchMessagesFilterPinned': SearchMessagesFilterPinned,
    'searchMessagesFilterUnreadMention': SearchMessagesFilterUnreadMention,
    'searchMessagesFilterUrl': SearchMessagesFilterUrl,
    'searchMessagesFilterVideo': SearchMessagesFilterVideo,
    'searchMessagesFilterVideoNote': SearchMessagesFilterVideoNote,
    'searchMessagesFilterVoiceAndVideoNote': SearchMessagesFilterVoiceAndVideoNote,
    'searchMessagesFilterVoiceNote': SearchMessagesFilterVoiceNote,
    'seconds': Seconds,
    'secretChat': SecretChat,
    'secretChatState': SecretChatState,
    'secretChatStateClosed': SecretChatStateClosed,
    'secretChatStatePending': SecretChatStatePending,
    'secretChatStateReady': SecretChatStateReady,
    'session': Session,
    'sessions': Sessions,
    'shippingOption': ShippingOption,
    'statisticalGraph': StatisticalGraph,
    'statisticalGraphAsync': StatisticalGraphAsync,
    'statisticalGraphData': StatisticalGraphData,
    'statisticalGraphError': StatisticalGraphError,
    'statisticalValue': StatisticalValue,
    'sticker': Sticker,
    'stickerSet': StickerSet,
    'stickerSetInfo': StickerSetInfo,
    'stickerSets': StickerSets,
    'stickers': Stickers,
    'storageStatistics': StorageStatistics,
    'storageStatisticsByChat': StorageStatisticsByChat,
    'storageStatisticsByFileType': StorageStatisticsByFileType,
    'storageStatisticsFast': StorageStatisticsFast,
    'suggestedAction': SuggestedAction,
    'suggestedActionCheckPhoneNumber': SuggestedActionCheckPhoneNumber,
    'suggestedActionConvertToBroadcastGroup': SuggestedActionConvertToBroadcastGroup,
    'suggestedActionEnableArchiveAndMuteNewChats': SuggestedActionEnableArchiveAndMuteNewChats,
    'suggestedActionSeeTicksHint': SuggestedActionSeeTicksHint,
    'supergroup': Supergroup,
    'supergroupFullInfo': SupergroupFullInfo,
    'supergroupMembersFilter': SupergroupMembersFilter,
    'supergroupMembersFilterAdministrators': SupergroupMembersFilterAdministrators,
    'supergroupMembersFilterBanned': SupergroupMembersFilterBanned,
    'supergroupMembersFilterBots': SupergroupMembersFilterBots,
    'supergroupMembersFilterContacts': SupergroupMembersFilterContacts,
    'supergroupMembersFilterMention': SupergroupMembersFilterMention,
    'supergroupMembersFilterRecent': SupergroupMembersFilterRecent,
    'supergroupMembersFilterRestricted': SupergroupMembersFilterRestricted,
    'supergroupMembersFilterSearch': SupergroupMembersFilterSearch,
    'tMeUrl': TMeUrl,
    'tMeUrlType': TMeUrlType,
    'tMeUrlTypeChatInvite': TMeUrlTypeChatInvite,
    'tMeUrlTypeStickerSet': TMeUrlTypeStickerSet,
    'tMeUrlTypeSupergroup': TMeUrlTypeSupergroup,
    'tMeUrlTypeUser': TMeUrlTypeUser,
    'tMeUrls': TMeUrls,
    'tdlibParameters': TdlibParameters,
    'temporaryPasswordState': TemporaryPasswordState,
    'termsOfService': TermsOfService,
    'testBytes': TestBytes,
    'testInt': TestInt,
    'testString': TestString,
    'testVectorInt': TestVectorInt,
    'testVectorIntObject': TestVectorIntObject,
    'testVectorString': TestVectorString,
    'testVectorStringObject': TestVectorStringObject,
    'text': Text,
    'textEntities': TextEntities,
    'textEntity': TextEntity,
    'textEntityType': TextEntityType,
    'textEntityTypeBankCardNumber': TextEntityTypeBankCardNumber,
    'textEntityTypeBold': TextEntityTypeBold,
    'textEntityTypeBotCommand': TextEntityTypeBotCommand,
    'textEntityTypeCashtag': TextEntityTypeCashtag,
    'textEntityTypeCode': TextEntityTypeCode,
    'textEntityTypeEmailAddress': TextEntityTypeEmailAddress,
    'textEntityTypeHashtag': TextEntityTypeHashtag,
    'textEntityTypeItalic': TextEntityTypeItalic,
    'textEntityTypeMention': TextEntityTypeMention,
    'textEntityTypeMentionName': TextEntityTypeMentionName,
    'textEntityTypePhoneNumber': TextEntityTypePhoneNumber,
    'textEntityTypePre': TextEntityTypePre,
    'textEntityTypePreCode': TextEntityTypePreCode,
    'textEntityTypeStrikethrough': TextEntityTypeStrikethrough,
    'textEntityTypeTextUrl': TextEntityTypeTextUrl,
    'textEntityTypeUnderline': TextEntityTypeUnderline,
    'textEntityTypeUrl': TextEntityTypeUrl,
    'textParseMode': TextParseMode,
    'textParseModeHTML': TextParseModeHTML,
    'textParseModeMarkdown': TextParseModeMarkdown,
    'thumbnail': Thumbnail,
    'thumbnailFormat': ThumbnailFormat,
    'thumbnailFormatGif': ThumbnailFormatGif,
    'thumbnailFormatJpeg': ThumbnailFormatJpeg,
    'thumbnailFormatMpeg4': ThumbnailFormatMpeg4,
    'thumbnailFormatPng': ThumbnailFormatPng,
    'thumbnailFormatTgs': ThumbnailFormatTgs,
    'thumbnailFormatWebp': ThumbnailFormatWebp,
    'topChatCategory': TopChatCategory,
    'topChatCategoryBots': TopChatCategoryBots,
    'topChatCategoryCalls': TopChatCategoryCalls,
    'topChatCategoryChannels': TopChatCategoryChannels,
    'topChatCategoryForwardChats': TopChatCategoryForwardChats,
    'topChatCategoryGroups': TopChatCategoryGroups,
    'topChatCategoryInlineBots': TopChatCategoryInlineBots,
    'topChatCategoryUsers': TopChatCategoryUsers,
    'update': Update,
    'updateActiveNotifications': UpdateActiveNotifications,
    'updateAnimationSearchParameters': UpdateAnimationSearchParameters,
    'updateAuthorizationState': UpdateAuthorizationState,
    'updateBasicGroup': UpdateBasicGroup,
    'updateBasicGroupFullInfo': UpdateBasicGroupFullInfo,
    'updateCall': UpdateCall,
    'updateChatActionBar': UpdateChatActionBar,
    'updateChatDefaultDisableNotification': UpdateChatDefaultDisableNotification,
    'updateChatDraftMessage': UpdateChatDraftMessage,
    'updateChatFilters': UpdateChatFilters,
    'updateChatHasScheduledMessages': UpdateChatHasScheduledMessages,
    'updateChatIsBlocked': UpdateChatIsBlocked,
    'updateChatIsMarkedAsUnread': UpdateChatIsMarkedAsUnread,
    'updateChatLastMessage': UpdateChatLastMessage,
    'updateChatMember': UpdateChatMember,
    'updateChatMessageTtlSetting': UpdateChatMessageTtlSetting,
    'updateChatNotificationSettings': UpdateChatNotificationSettings,
    'updateChatOnlineMemberCount': UpdateChatOnlineMemberCount,
    'updateChatPermissions': UpdateChatPermissions,
    'updateChatPhoto': UpdateChatPhoto,
    'updateChatPosition': UpdateChatPosition,
    'updateChatReadInbox': UpdateChatReadInbox,
    'updateChatReadOutbox': UpdateChatReadOutbox,
    'updateChatReplyMarkup': UpdateChatReplyMarkup,
    'updateChatTitle': UpdateChatTitle,
    'updateChatUnreadMentionCount': UpdateChatUnreadMentionCount,
    'updateChatVoiceChat': UpdateChatVoiceChat,
    'updateConnectionState': UpdateConnectionState,
    'updateDeleteMessages': UpdateDeleteMessages,
    'updateDiceEmojis': UpdateDiceEmojis,
    'updateFavoriteStickers': UpdateFavoriteStickers,
    'updateFile': UpdateFile,
    'updateFileGenerationStart': UpdateFileGenerationStart,
    'updateFileGenerationStop': UpdateFileGenerationStop,
    'updateGroupCall': UpdateGroupCall,
    'updateGroupCallParticipant': UpdateGroupCallParticipant,
    'updateHavePendingNotifications': UpdateHavePendingNotifications,
    'updateInstalledStickerSets': UpdateInstalledStickerSets,
    'updateLanguagePackStrings': UpdateLanguagePackStrings,
    'updateMessageContent': UpdateMessageContent,
    'updateMessageContentOpened': UpdateMessageContentOpened,
    'updateMessageEdited': UpdateMessageEdited,
    'updateMessageInteractionInfo': UpdateMessageInteractionInfo,
    'updateMessageIsPinned': UpdateMessageIsPinned,
    'updateMessageLiveLocationViewed': UpdateMessageLiveLocationViewed,
    'updateMessageMentionRead': UpdateMessageMentionRead,
    'updateMessageSendAcknowledged': UpdateMessageSendAcknowledged,
    'updateMessageSendFailed': UpdateMessageSendFailed,
    'updateMessageSendSucceeded': UpdateMessageSendSucceeded,
    'updateNewCallSignalingData': UpdateNewCallSignalingData,
    'updateNewCallbackQuery': UpdateNewCallbackQuery,
    'updateNewChat': UpdateNewChat,
    'updateNewChosenInlineResult': UpdateNewChosenInlineResult,
    'updateNewCustomEvent': UpdateNewCustomEvent,
    'updateNewCustomQuery': UpdateNewCustomQuery,
    'updateNewInlineCallbackQuery': UpdateNewInlineCallbackQuery,
    'updateNewInlineQuery': UpdateNewInlineQuery,
    'updateNewMessage': UpdateNewMessage,
    'updateNewPreCheckoutQuery': UpdateNewPreCheckoutQuery,
    'updateNewShippingQuery': UpdateNewShippingQuery,
    'updateNotification': UpdateNotification,
    'updateNotificationGroup': UpdateNotificationGroup,
    'updateOption': UpdateOption,
    'updatePoll': UpdatePoll,
    'updatePollAnswer': UpdatePollAnswer,
    'updateRecentStickers': UpdateRecentStickers,
    'updateSavedAnimations': UpdateSavedAnimations,
    'updateScopeNotificationSettings': UpdateScopeNotificationSettings,
    'updateSecretChat': UpdateSecretChat,
    'updateSelectedBackground': UpdateSelectedBackground,
    'updateServiceNotification': UpdateServiceNotification,
    'updateStickerSet': UpdateStickerSet,
    'updateSuggestedActions': UpdateSuggestedActions,
    'updateSupergroup': UpdateSupergroup,
    'updateSupergroupFullInfo': UpdateSupergroupFullInfo,
    'updateTermsOfService': UpdateTermsOfService,
    'updateTrendingStickerSets': UpdateTrendingStickerSets,
    'updateUnreadChatCount': UpdateUnreadChatCount,
    'updateUnreadMessageCount': UpdateUnreadMessageCount,
    'updateUser': UpdateUser,
    'updateUserChatAction': UpdateUserChatAction,
    'updateUserFullInfo': UpdateUserFullInfo,
    'updateUserPrivacySettingRules': UpdateUserPrivacySettingRules,
    'updateUserStatus': UpdateUserStatus,
    'updateUsersNearby': UpdateUsersNearby,
    'updates': Updates,
    'user': User,
    'userFullInfo': UserFullInfo,
    'userPrivacySetting': UserPrivacySetting,
    'userPrivacySettingAllowCalls': UserPrivacySettingAllowCalls,
    'userPrivacySettingAllowChatInvites': UserPrivacySettingAllowChatInvites,
    'userPrivacySettingAllowFindingByPhoneNumber': UserPrivacySettingAllowFindingByPhoneNumber,
    'userPrivacySettingAllowPeerToPeerCalls': UserPrivacySettingAllowPeerToPeerCalls,
    'userPrivacySettingShowLinkInForwardedMessages': UserPrivacySettingShowLinkInForwardedMessages,
    'userPrivacySettingShowPhoneNumber': UserPrivacySettingShowPhoneNumber,
    'userPrivacySettingShowProfilePhoto': UserPrivacySettingShowProfilePhoto,
    'userPrivacySettingShowStatus': UserPrivacySettingShowStatus,
    'userPrivacySettingRule': UserPrivacySettingRule,
    'userPrivacySettingRuleAllowAll': UserPrivacySettingRuleAllowAll,
    'userPrivacySettingRuleAllowChatMembers': UserPrivacySettingRuleAllowChatMembers,
    'userPrivacySettingRuleAllowContacts': UserPrivacySettingRuleAllowContacts,
    'userPrivacySettingRuleAllowUsers': UserPrivacySettingRuleAllowUsers,
    'userPrivacySettingRuleRestrictAll': UserPrivacySettingRuleRestrictAll,
    'userPrivacySettingRuleRestrictChatMembers': UserPrivacySettingRuleRestrictChatMembers,
    'userPrivacySettingRuleRestrictContacts': UserPrivacySettingRuleRestrictContacts,
    'userPrivacySettingRuleRestrictUsers': UserPrivacySettingRuleRestrictUsers,
    'userPrivacySettingRules': UserPrivacySettingRules,
    'userStatus': UserStatus,
    'userStatusEmpty': UserStatusEmpty,
    'userStatusLastMonth': UserStatusLastMonth,
    'userStatusLastWeek': UserStatusLastWeek,
    'userStatusOffline': UserStatusOffline,
    'userStatusOnline': UserStatusOnline,
    'userStatusRecently': UserStatusRecently,
    'userType': UserType,
    'userTypeBot': UserTypeBot,
    'userTypeDeleted': UserTypeDeleted,
    'userTypeRegular': UserTypeRegular,
    'userTypeUnknown': UserTypeUnknown,
    'users': Users,
    'validatedOrderInfo': ValidatedOrderInfo,
    'vectorPathCommand': VectorPathCommand,
    'vectorPathCommandCubicBezierCurve': VectorPathCommandCubicBezierCurve,
    'vectorPathCommandLine': VectorPathCommandLine,
    'venue': Venue,
    'video': Video,
    'videoNote': VideoNote,
    'voiceChat': VoiceChat,
    'voiceNote': VoiceNote,
    'webPage': WebPage,
    'webPageInstantView': WebPageInstantView,
}

__all__ = [
    'AioTDLibError',
    'API',
    'BaseObject',

    # Types and Functions
    'AcceptCall',
    'AcceptTermsOfService',
    'AccountTtl',
    'AddChatMember',
    'AddChatMembers',
    'AddChatToList',
    'AddContact',
    'AddCustomServerLanguagePack',
    'AddFavoriteSticker',
    'AddLocalMessage',
    'AddLogMessage',
    'AddNetworkStatistics',
    'AddProxy',
    'AddRecentSticker',
    'AddRecentlyFoundChat',
    'AddSavedAnimation',
    'AddStickerToSet',
    'Address',
    'AnimatedChatPhoto',
    'Animation',
    'Animations',
    'AnswerCallbackQuery',
    'AnswerCustomQuery',
    'AnswerInlineQuery',
    'AnswerPreCheckoutQuery',
    'AnswerShippingQuery',
    'Audio',
    'AuthenticationCodeInfo',
    'AuthenticationCodeType',
    'AuthenticationCodeTypeCall',
    'AuthenticationCodeTypeFlashCall',
    'AuthenticationCodeTypeSms',
    'AuthenticationCodeTypeTelegramMessage',
    'AuthorizationState',
    'AuthorizationStateClosed',
    'AuthorizationStateClosing',
    'AuthorizationStateLoggingOut',
    'AuthorizationStateReady',
    'AuthorizationStateWaitCode',
    'AuthorizationStateWaitEncryptionKey',
    'AuthorizationStateWaitOtherDeviceConfirmation',
    'AuthorizationStateWaitPassword',
    'AuthorizationStateWaitPhoneNumber',
    'AuthorizationStateWaitRegistration',
    'AuthorizationStateWaitTdlibParameters',
    'AutoDownloadSettings',
    'AutoDownloadSettingsPresets',
    'Background',
    'BackgroundFill',
    'BackgroundFillGradient',
    'BackgroundFillSolid',
    'BackgroundType',
    'BackgroundTypeFill',
    'BackgroundTypePattern',
    'BackgroundTypeWallpaper',
    'Backgrounds',
    'BanChatMember',
    'BankCardActionOpenUrl',
    'BankCardInfo',
    'BasicGroup',
    'BasicGroupFullInfo',
    'BlockMessageSenderFromReplies',
    'BotCommand',
    'BotInfo',
    'Call',
    'CallDiscardReason',
    'CallDiscardReasonDeclined',
    'CallDiscardReasonDisconnected',
    'CallDiscardReasonEmpty',
    'CallDiscardReasonHungUp',
    'CallDiscardReasonMissed',
    'CallId',
    'CallProblem',
    'CallProblemDistortedSpeech',
    'CallProblemDistortedVideo',
    'CallProblemDropped',
    'CallProblemEcho',
    'CallProblemInterruptions',
    'CallProblemNoise',
    'CallProblemPixelatedVideo',
    'CallProblemSilentLocal',
    'CallProblemSilentRemote',
    'CallProtocol',
    'CallServer',
    'CallServerType',
    'CallServerTypeTelegramReflector',
    'CallServerTypeWebrtc',
    'CallState',
    'CallStateDiscarded',
    'CallStateError',
    'CallStateExchangingKeys',
    'CallStateHangingUp',
    'CallStatePending',
    'CallStateReady',
    'CallbackQueryAnswer',
    'CallbackQueryPayload',
    'CallbackQueryPayloadData',
    'CallbackQueryPayloadDataWithPassword',
    'CallbackQueryPayloadGame',
    'CanTransferOwnership',
    'CanTransferOwnershipResult',
    'CanTransferOwnershipResultOk',
    'CanTransferOwnershipResultPasswordNeeded',
    'CanTransferOwnershipResultPasswordTooFresh',
    'CanTransferOwnershipResultSessionTooFresh',
    'CancelDownloadFile',
    'CancelUploadFile',
    'ChangeImportedContacts',
    'ChangePhoneNumber',
    'ChangeStickerSet',
    'Chat',
    'ChatAction',
    'ChatActionCancel',
    'ChatActionChoosingContact',
    'ChatActionChoosingLocation',
    'ChatActionRecordingVideo',
    'ChatActionRecordingVideoNote',
    'ChatActionRecordingVoiceNote',
    'ChatActionStartPlayingGame',
    'ChatActionTyping',
    'ChatActionUploadingDocument',
    'ChatActionUploadingPhoto',
    'ChatActionUploadingVideo',
    'ChatActionUploadingVideoNote',
    'ChatActionUploadingVoiceNote',
    'ChatActionBar',
    'ChatActionBarAddContact',
    'ChatActionBarInviteMembers',
    'ChatActionBarReportAddBlock',
    'ChatActionBarReportSpam',
    'ChatActionBarReportUnrelatedLocation',
    'ChatActionBarSharePhoneNumber',
    'ChatAdministrator',
    'ChatAdministrators',
    'ChatEvent',
    'ChatEventAction',
    'ChatEventDescriptionChanged',
    'ChatEventInviteLinkDeleted',
    'ChatEventInviteLinkEdited',
    'ChatEventInviteLinkRevoked',
    'ChatEventInvitesToggled',
    'ChatEventIsAllHistoryAvailableToggled',
    'ChatEventLinkedChatChanged',
    'ChatEventLocationChanged',
    'ChatEventMemberInvited',
    'ChatEventMemberJoined',
    'ChatEventMemberJoinedByInviteLink',
    'ChatEventMemberLeft',
    'ChatEventMemberPromoted',
    'ChatEventMemberRestricted',
    'ChatEventMessageDeleted',
    'ChatEventMessageEdited',
    'ChatEventMessagePinned',
    'ChatEventMessageTtlSettingChanged',
    'ChatEventMessageUnpinned',
    'ChatEventPermissionsChanged',
    'ChatEventPhotoChanged',
    'ChatEventPollStopped',
    'ChatEventSignMessagesToggled',
    'ChatEventSlowModeDelayChanged',
    'ChatEventStickerSetChanged',
    'ChatEventTitleChanged',
    'ChatEventUsernameChanged',
    'ChatEventVoiceChatCreated',
    'ChatEventVoiceChatDiscarded',
    'ChatEventVoiceChatMuteNewParticipantsToggled',
    'ChatEventVoiceChatParticipantIsMutedToggled',
    'ChatEventVoiceChatParticipantVolumeLevelChanged',
    'ChatEventLogFilters',
    'ChatEvents',
    'ChatFilter',
    'ChatFilterInfo',
    'ChatInviteLink',
    'ChatInviteLinkCount',
    'ChatInviteLinkCounts',
    'ChatInviteLinkInfo',
    'ChatInviteLinkMember',
    'ChatInviteLinkMembers',
    'ChatInviteLinks',
    'ChatList',
    'ChatListArchive',
    'ChatListFilter',
    'ChatListMain',
    'ChatLists',
    'ChatLocation',
    'ChatMember',
    'ChatMemberStatus',
    'ChatMemberStatusAdministrator',
    'ChatMemberStatusBanned',
    'ChatMemberStatusCreator',
    'ChatMemberStatusLeft',
    'ChatMemberStatusMember',
    'ChatMemberStatusRestricted',
    'ChatMembers',
    'ChatMembersFilter',
    'ChatMembersFilterAdministrators',
    'ChatMembersFilterBanned',
    'ChatMembersFilterBots',
    'ChatMembersFilterContacts',
    'ChatMembersFilterMembers',
    'ChatMembersFilterMention',
    'ChatMembersFilterRestricted',
    'ChatNearby',
    'ChatNotificationSettings',
    'ChatPermissions',
    'ChatPhoto',
    'ChatPhotoInfo',
    'ChatPhotos',
    'ChatPosition',
    'ChatReportReason',
    'ChatReportReasonChildAbuse',
    'ChatReportReasonCopyright',
    'ChatReportReasonCustom',
    'ChatReportReasonFake',
    'ChatReportReasonPornography',
    'ChatReportReasonSpam',
    'ChatReportReasonUnrelatedLocation',
    'ChatReportReasonViolence',
    'ChatSource',
    'ChatSourceMtprotoProxy',
    'ChatSourcePublicServiceAnnouncement',
    'ChatStatistics',
    'ChatStatisticsChannel',
    'ChatStatisticsSupergroup',
    'ChatStatisticsAdministratorActionsInfo',
    'ChatStatisticsInviterInfo',
    'ChatStatisticsMessageInteractionInfo',
    'ChatStatisticsMessageSenderInfo',
    'ChatType',
    'ChatTypeBasicGroup',
    'ChatTypePrivate',
    'ChatTypeSecret',
    'ChatTypeSupergroup',
    'Chats',
    'ChatsNearby',
    'CheckAuthenticationBotToken',
    'CheckAuthenticationCode',
    'CheckAuthenticationPassword',
    'CheckChangePhoneNumberCode',
    'CheckChatInviteLink',
    'CheckChatUsername',
    'CheckChatUsernameResult',
    'CheckChatUsernameResultOk',
    'CheckChatUsernameResultPublicChatsTooMuch',
    'CheckChatUsernameResultPublicGroupsUnavailable',
    'CheckChatUsernameResultUsernameInvalid',
    'CheckChatUsernameResultUsernameOccupied',
    'CheckCreatedPublicChatsLimit',
    'CheckDatabaseEncryptionKey',
    'CheckEmailAddressVerificationCode',
    'CheckPhoneNumberConfirmationCode',
    'CheckPhoneNumberVerificationCode',
    'CheckRecoveryEmailAddressCode',
    'CleanFileName',
    'ClearAllDraftMessages',
    'ClearImportedContacts',
    'ClearRecentStickers',
    'ClearRecentlyFoundChats',
    'Close',
    'CloseChat',
    'CloseSecretChat',
    'ClosedVectorPath',
    'ConfirmQrCodeAuthentication',
    'ConnectedWebsite',
    'ConnectedWebsites',
    'ConnectionState',
    'ConnectionStateConnecting',
    'ConnectionStateConnectingToProxy',
    'ConnectionStateReady',
    'ConnectionStateUpdating',
    'ConnectionStateWaitingForNetwork',
    'Contact',
    'Count',
    'Countries',
    'CountryInfo',
    'CreateBasicGroupChat',
    'CreateCall',
    'CreateChatFilter',
    'CreateChatInviteLink',
    'CreateNewBasicGroupChat',
    'CreateNewSecretChat',
    'CreateNewStickerSet',
    'CreateNewSupergroupChat',
    'CreatePrivateChat',
    'CreateSecretChat',
    'CreateSupergroupChat',
    'CreateTemporaryPassword',
    'CreateVoiceChat',
    'CustomRequestResult',
    'DatabaseStatistics',
    'Date',
    'DateRange',
    'DatedFile',
    'DeepLinkInfo',
    'DeleteAccount',
    'DeleteAllCallMessages',
    'DeleteAllRevokedChatInviteLinks',
    'DeleteChat',
    'DeleteChatFilter',
    'DeleteChatHistory',
    'DeleteChatMessagesFromUser',
    'DeleteChatReplyMarkup',
    'DeleteFile',
    'DeleteLanguagePack',
    'DeleteMessages',
    'DeletePassportElement',
    'DeleteProfilePhoto',
    'DeleteRevokedChatInviteLink',
    'DeleteSavedCredentials',
    'DeleteSavedOrderInfo',
    'Destroy',
    'DeviceToken',
    'DeviceTokenApplePush',
    'DeviceTokenApplePushVoIP',
    'DeviceTokenBlackBerryPush',
    'DeviceTokenFirebaseCloudMessaging',
    'DeviceTokenMicrosoftPush',
    'DeviceTokenMicrosoftPushVoIP',
    'DeviceTokenSimplePush',
    'DeviceTokenTizenPush',
    'DeviceTokenUbuntuPush',
    'DeviceTokenWebPush',
    'DeviceTokenWindowsPush',
    'DiceStickers',
    'DiceStickersRegular',
    'DiceStickersSlotMachine',
    'DisableProxy',
    'DiscardCall',
    'DiscardGroupCall',
    'DisconnectAllWebsites',
    'DisconnectWebsite',
    'Document',
    'DownloadFile',
    'DraftMessage',
    'EditChatFilter',
    'EditChatInviteLink',
    'EditCustomLanguagePackInfo',
    'EditInlineMessageCaption',
    'EditInlineMessageLiveLocation',
    'EditInlineMessageMedia',
    'EditInlineMessageReplyMarkup',
    'EditInlineMessageText',
    'EditMessageCaption',
    'EditMessageLiveLocation',
    'EditMessageMedia',
    'EditMessageReplyMarkup',
    'EditMessageSchedulingState',
    'EditMessageText',
    'EditProxy',
    'EmailAddressAuthenticationCodeInfo',
    'Emojis',
    'EnableProxy',
    'EncryptedCredentials',
    'EncryptedPassportElement',
    'EndGroupCallRecording',
    'Error',
    'File',
    'FilePart',
    'FileType',
    'FileTypeAnimation',
    'FileTypeAudio',
    'FileTypeDocument',
    'FileTypeNone',
    'FileTypePhoto',
    'FileTypeProfilePhoto',
    'FileTypeSecret',
    'FileTypeSecretThumbnail',
    'FileTypeSecure',
    'FileTypeSticker',
    'FileTypeThumbnail',
    'FileTypeUnknown',
    'FileTypeVideo',
    'FileTypeVideoNote',
    'FileTypeVoiceNote',
    'FileTypeWallpaper',
    'FinishFileGeneration',
    'FormattedText',
    'ForwardMessages',
    'FoundMessages',
    'Game',
    'GameHighScore',
    'GameHighScores',
    'GetAccountTtl',
    'GetActiveLiveLocationMessages',
    'GetActiveSessions',
    'GetAllPassportElements',
    'GetApplicationConfig',
    'GetArchivedStickerSets',
    'GetAttachedStickerSets',
    'GetAuthorizationState',
    'GetAutoDownloadSettingsPresets',
    'GetAvailableVoiceChatAliases',
    'GetBackgroundUrl',
    'GetBackgrounds',
    'GetBankCardInfo',
    'GetBasicGroup',
    'GetBasicGroupFullInfo',
    'GetBlockedMessageSenders',
    'GetCallbackQueryAnswer',
    'GetCallbackQueryMessage',
    'GetChat',
    'GetChatAdministrators',
    'GetChatEventLog',
    'GetChatFilter',
    'GetChatFilterDefaultIconName',
    'GetChatHistory',
    'GetChatInviteLink',
    'GetChatInviteLinkCounts',
    'GetChatInviteLinkMembers',
    'GetChatInviteLinks',
    'GetChatListsToAddChat',
    'GetChatMember',
    'GetChatMessageByDate',
    'GetChatMessageCount',
    'GetChatNotificationSettingsExceptions',
    'GetChatPinnedMessage',
    'GetChatScheduledMessages',
    'GetChatStatistics',
    'GetChatStatisticsUrl',
    'GetChats',
    'GetConnectedWebsites',
    'GetContacts',
    'GetCountries',
    'GetCountryCode',
    'GetCreatedPublicChats',
    'GetCurrentState',
    'GetDatabaseStatistics',
    'GetDeepLinkInfo',
    'GetEmojiSuggestionsUrl',
    'GetExternalLink',
    'GetExternalLinkInfo',
    'GetFavoriteStickers',
    'GetFile',
    'GetFileDownloadedPrefixSize',
    'GetFileExtension',
    'GetFileMimeType',
    'GetGameHighScores',
    'GetGroupCall',
    'GetGroupCallInviteLink',
    'GetGroupCallStreamSegment',
    'GetGroupsInCommon',
    'GetImportedContactCount',
    'GetInactiveSupergroupChats',
    'GetInlineGameHighScores',
    'GetInlineQueryResults',
    'GetInstalledStickerSets',
    'GetInviteText',
    'GetJsonString',
    'GetJsonValue',
    'GetLanguagePackInfo',
    'GetLanguagePackString',
    'GetLanguagePackStrings',
    'GetLocalizationTargetInfo',
    'GetLogStream',
    'GetLogTagVerbosityLevel',
    'GetLogTags',
    'GetLogVerbosityLevel',
    'GetLoginUrl',
    'GetLoginUrlInfo',
    'GetMapThumbnailFile',
    'GetMarkdownText',
    'GetMe',
    'GetMessage',
    'GetMessageEmbeddingCode',
    'GetMessageFileType',
    'GetMessageImportConfirmationText',
    'GetMessageLink',
    'GetMessageLinkInfo',
    'GetMessageLocally',
    'GetMessagePublicForwards',
    'GetMessageStatistics',
    'GetMessageThread',
    'GetMessageThreadHistory',
    'GetMessages',
    'GetNetworkStatistics',
    'GetOption',
    'GetPassportAuthorizationForm',
    'GetPassportAuthorizationFormAvailableElements',
    'GetPassportElement',
    'GetPasswordState',
    'GetPaymentForm',
    'GetPaymentReceipt',
    'GetPhoneNumberInfo',
    'GetPollVoters',
    'GetPreferredCountryLanguage',
    'GetProxies',
    'GetProxyLink',
    'GetPushReceiverId',
    'GetRecentInlineBots',
    'GetRecentStickers',
    'GetRecentlyVisitedTMeUrls',
    'GetRecommendedChatFilters',
    'GetRecoveryEmailAddress',
    'GetRemoteFile',
    'GetRepliedMessage',
    'GetSavedAnimations',
    'GetSavedOrderInfo',
    'GetScopeNotificationSettings',
    'GetSecretChat',
    'GetStatisticalGraph',
    'GetStickerEmojis',
    'GetStickerSet',
    'GetStickers',
    'GetStorageStatistics',
    'GetStorageStatisticsFast',
    'GetSuitableDiscussionChats',
    'GetSupergroup',
    'GetSupergroupFullInfo',
    'GetSupergroupMembers',
    'GetSupportUser',
    'GetTemporaryPasswordState',
    'GetTextEntities',
    'GetTopChats',
    'GetTrendingStickerSets',
    'GetUser',
    'GetUserFullInfo',
    'GetUserPrivacySettingRules',
    'GetUserProfilePhotos',
    'GetWebPageInstantView',
    'GetWebPagePreview',
    'GroupCall',
    'GroupCallId',
    'GroupCallJoinResponse',
    'GroupCallJoinResponseStream',
    'GroupCallJoinResponseWebrtc',
    'GroupCallJoinResponseCandidate',
    'GroupCallParticipant',
    'GroupCallPayload',
    'GroupCallPayloadFingerprint',
    'GroupCallRecentSpeaker',
    'Hashtags',
    'HideSuggestedAction',
    'HttpUrl',
    'IdentityDocument',
    'ImportContacts',
    'ImportMessages',
    'ImportedContacts',
    'InlineKeyboardButton',
    'InlineKeyboardButtonType',
    'InlineKeyboardButtonTypeBuy',
    'InlineKeyboardButtonTypeCallback',
    'InlineKeyboardButtonTypeCallbackGame',
    'InlineKeyboardButtonTypeCallbackWithPassword',
    'InlineKeyboardButtonTypeLoginUrl',
    'InlineKeyboardButtonTypeSwitchInline',
    'InlineKeyboardButtonTypeUrl',
    'InlineQueryResult',
    'InlineQueryResultAnimation',
    'InlineQueryResultArticle',
    'InlineQueryResultAudio',
    'InlineQueryResultContact',
    'InlineQueryResultDocument',
    'InlineQueryResultGame',
    'InlineQueryResultLocation',
    'InlineQueryResultPhoto',
    'InlineQueryResultSticker',
    'InlineQueryResultVenue',
    'InlineQueryResultVideo',
    'InlineQueryResultVoiceNote',
    'InlineQueryResults',
    'InputBackground',
    'InputBackgroundLocal',
    'InputBackgroundRemote',
    'InputChatPhoto',
    'InputChatPhotoAnimation',
    'InputChatPhotoPrevious',
    'InputChatPhotoStatic',
    'InputCredentials',
    'InputCredentialsApplePay',
    'InputCredentialsGooglePay',
    'InputCredentialsNew',
    'InputCredentialsSaved',
    'InputFile',
    'InputFileGenerated',
    'InputFileId',
    'InputFileLocal',
    'InputFileRemote',
    'InputIdentityDocument',
    'InputInlineQueryResult',
    'InputInlineQueryResultAnimation',
    'InputInlineQueryResultArticle',
    'InputInlineQueryResultAudio',
    'InputInlineQueryResultContact',
    'InputInlineQueryResultDocument',
    'InputInlineQueryResultGame',
    'InputInlineQueryResultLocation',
    'InputInlineQueryResultPhoto',
    'InputInlineQueryResultSticker',
    'InputInlineQueryResultVenue',
    'InputInlineQueryResultVideo',
    'InputInlineQueryResultVoiceNote',
    'InputMessageContent',
    'InputMessageAnimation',
    'InputMessageAudio',
    'InputMessageContact',
    'InputMessageDice',
    'InputMessageDocument',
    'InputMessageForwarded',
    'InputMessageGame',
    'InputMessageInvoice',
    'InputMessageLocation',
    'InputMessagePhoto',
    'InputMessagePoll',
    'InputMessageSticker',
    'InputMessageText',
    'InputMessageVenue',
    'InputMessageVideo',
    'InputMessageVideoNote',
    'InputMessageVoiceNote',
    'InputPassportElement',
    'InputPassportElementAddress',
    'InputPassportElementBankStatement',
    'InputPassportElementDriverLicense',
    'InputPassportElementEmailAddress',
    'InputPassportElementIdentityCard',
    'InputPassportElementInternalPassport',
    'InputPassportElementPassport',
    'InputPassportElementPassportRegistration',
    'InputPassportElementPersonalDetails',
    'InputPassportElementPhoneNumber',
    'InputPassportElementRentalAgreement',
    'InputPassportElementTemporaryRegistration',
    'InputPassportElementUtilityBill',
    'InputPassportElementError',
    'InputPassportElementErrorSource',
    'InputPassportElementErrorSourceDataField',
    'InputPassportElementErrorSourceFile',
    'InputPassportElementErrorSourceFiles',
    'InputPassportElementErrorSourceFrontSide',
    'InputPassportElementErrorSourceReverseSide',
    'InputPassportElementErrorSourceSelfie',
    'InputPassportElementErrorSourceTranslationFile',
    'InputPassportElementErrorSourceTranslationFiles',
    'InputPassportElementErrorSourceUnspecified',
    'InputPersonalDocument',
    'InputSticker',
    'InputStickerAnimated',
    'InputStickerStatic',
    'InputThumbnail',
    'InviteGroupCallParticipants',
    'Invoice',
    'JoinChat',
    'JoinChatByInviteLink',
    'JoinGroupCall',
    'JsonValue',
    'JsonValueArray',
    'JsonValueBoolean',
    'JsonValueNull',
    'JsonValueNumber',
    'JsonValueObject',
    'JsonValueString',
    'KeyboardButton',
    'KeyboardButtonType',
    'KeyboardButtonTypeRequestLocation',
    'KeyboardButtonTypeRequestPhoneNumber',
    'KeyboardButtonTypeRequestPoll',
    'KeyboardButtonTypeText',
    'LabeledPricePart',
    'LanguagePackInfo',
    'LanguagePackString',
    'LanguagePackStringValue',
    'LanguagePackStringValueDeleted',
    'LanguagePackStringValueOrdinary',
    'LanguagePackStringValuePluralized',
    'LanguagePackStrings',
    'LeaveChat',
    'LeaveGroupCall',
    'LoadGroupCallParticipants',
    'LocalFile',
    'LocalizationTargetInfo',
    'Location',
    'LogOut',
    'LogStream',
    'LogStreamDefault',
    'LogStreamEmpty',
    'LogStreamFile',
    'LogTags',
    'LogVerbosityLevel',
    'LoginUrlInfo',
    'LoginUrlInfoOpen',
    'LoginUrlInfoRequestConfirmation',
    'MaskPoint',
    'MaskPointChin',
    'MaskPointEyes',
    'MaskPointForehead',
    'MaskPointMouth',
    'MaskPosition',
    'Message',
    'MessageContent',
    'MessageAnimation',
    'MessageAudio',
    'MessageBasicGroupChatCreate',
    'MessageCall',
    'MessageChatAddMembers',
    'MessageChatChangePhoto',
    'MessageChatChangeTitle',
    'MessageChatDeleteMember',
    'MessageChatDeletePhoto',
    'MessageChatJoinByLink',
    'MessageChatSetTtl',
    'MessageChatUpgradeFrom',
    'MessageChatUpgradeTo',
    'MessageContact',
    'MessageContactRegistered',
    'MessageCustomServiceAction',
    'MessageDice',
    'MessageDocument',
    'MessageExpiredPhoto',
    'MessageExpiredVideo',
    'MessageGame',
    'MessageGameScore',
    'MessageInviteVoiceChatParticipants',
    'MessageInvoice',
    'MessageLocation',
    'MessagePassportDataReceived',
    'MessagePassportDataSent',
    'MessagePaymentSuccessful',
    'MessagePaymentSuccessfulBot',
    'MessagePhoto',
    'MessagePinMessage',
    'MessagePoll',
    'MessageProximityAlertTriggered',
    'MessageScreenshotTaken',
    'MessageSticker',
    'MessageSupergroupChatCreate',
    'MessageText',
    'MessageUnsupported',
    'MessageVenue',
    'MessageVideo',
    'MessageVideoNote',
    'MessageVoiceChatEnded',
    'MessageVoiceChatStarted',
    'MessageVoiceNote',
    'MessageWebsiteConnected',
    'MessageCopyOptions',
    'MessageFileType',
    'MessageFileTypeGroup',
    'MessageFileTypePrivate',
    'MessageFileTypeUnknown',
    'MessageForwardInfo',
    'MessageForwardOrigin',
    'MessageForwardOriginChannel',
    'MessageForwardOriginChat',
    'MessageForwardOriginHiddenUser',
    'MessageForwardOriginMessageImport',
    'MessageForwardOriginUser',
    'MessageInteractionInfo',
    'MessageLink',
    'MessageLinkInfo',
    'MessageReplyInfo',
    'MessageSchedulingState',
    'MessageSchedulingStateSendAtDate',
    'MessageSchedulingStateSendWhenOnline',
    'MessageSendOptions',
    'MessageSender',
    'MessageSenderChat',
    'MessageSenderUser',
    'MessageSenders',
    'MessageSendingState',
    'MessageSendingStateFailed',
    'MessageSendingStatePending',
    'MessageStatistics',
    'MessageThreadInfo',
    'Messages',
    'Minithumbnail',
    'NetworkStatistics',
    'NetworkStatisticsEntry',
    'NetworkStatisticsEntryCall',
    'NetworkStatisticsEntryFile',
    'NetworkType',
    'NetworkTypeMobile',
    'NetworkTypeMobileRoaming',
    'NetworkTypeNone',
    'NetworkTypeOther',
    'NetworkTypeWiFi',
    'Notification',
    'NotificationGroup',
    'NotificationGroupType',
    'NotificationGroupTypeCalls',
    'NotificationGroupTypeMentions',
    'NotificationGroupTypeMessages',
    'NotificationGroupTypeSecretChat',
    'NotificationSettingsScope',
    'NotificationSettingsScopeChannelChats',
    'NotificationSettingsScopeGroupChats',
    'NotificationSettingsScopePrivateChats',
    'NotificationType',
    'NotificationTypeNewCall',
    'NotificationTypeNewMessage',
    'NotificationTypeNewPushMessage',
    'NotificationTypeNewSecretChat',
    'Ok',
    'OpenChat',
    'OpenMessageContent',
    'OptimizeStorage',
    'OptionValue',
    'OptionValueBoolean',
    'OptionValueEmpty',
    'OptionValueInteger',
    'OptionValueString',
    'OrderInfo',
    'PageBlock',
    'PageBlockAnchor',
    'PageBlockAnimation',
    'PageBlockAudio',
    'PageBlockAuthorDate',
    'PageBlockBlockQuote',
    'PageBlockChatLink',
    'PageBlockCollage',
    'PageBlockCover',
    'PageBlockDetails',
    'PageBlockDivider',
    'PageBlockEmbedded',
    'PageBlockEmbeddedPost',
    'PageBlockFooter',
    'PageBlockHeader',
    'PageBlockKicker',
    'PageBlockList',
    'PageBlockMap',
    'PageBlockParagraph',
    'PageBlockPhoto',
    'PageBlockPreformatted',
    'PageBlockPullQuote',
    'PageBlockRelatedArticles',
    'PageBlockSlideshow',
    'PageBlockSubheader',
    'PageBlockSubtitle',
    'PageBlockTable',
    'PageBlockTitle',
    'PageBlockVideo',
    'PageBlockVoiceNote',
    'PageBlockCaption',
    'PageBlockHorizontalAlignment',
    'PageBlockHorizontalAlignmentCenter',
    'PageBlockHorizontalAlignmentLeft',
    'PageBlockHorizontalAlignmentRight',
    'PageBlockRelatedArticle',
    'PageBlockTableCell',
    'PageBlockVerticalAlignment',
    'PageBlockVerticalAlignmentBottom',
    'PageBlockVerticalAlignmentMiddle',
    'PageBlockVerticalAlignmentTop',
    'ParseMarkdown',
    'ParseTextEntities',
    'PassportAuthorizationForm',
    'PassportElement',
    'PassportElementAddress',
    'PassportElementBankStatement',
    'PassportElementDriverLicense',
    'PassportElementEmailAddress',
    'PassportElementIdentityCard',
    'PassportElementInternalPassport',
    'PassportElementPassport',
    'PassportElementPassportRegistration',
    'PassportElementPersonalDetails',
    'PassportElementPhoneNumber',
    'PassportElementRentalAgreement',
    'PassportElementTemporaryRegistration',
    'PassportElementUtilityBill',
    'PassportElementError',
    'PassportElementErrorSource',
    'PassportElementErrorSourceDataField',
    'PassportElementErrorSourceFile',
    'PassportElementErrorSourceFiles',
    'PassportElementErrorSourceFrontSide',
    'PassportElementErrorSourceReverseSide',
    'PassportElementErrorSourceSelfie',
    'PassportElementErrorSourceTranslationFile',
    'PassportElementErrorSourceTranslationFiles',
    'PassportElementErrorSourceUnspecified',
    'PassportElementType',
    'PassportElementTypeAddress',
    'PassportElementTypeBankStatement',
    'PassportElementTypeDriverLicense',
    'PassportElementTypeEmailAddress',
    'PassportElementTypeIdentityCard',
    'PassportElementTypeInternalPassport',
    'PassportElementTypePassport',
    'PassportElementTypePassportRegistration',
    'PassportElementTypePersonalDetails',
    'PassportElementTypePhoneNumber',
    'PassportElementTypeRentalAgreement',
    'PassportElementTypeTemporaryRegistration',
    'PassportElementTypeUtilityBill',
    'PassportElements',
    'PassportElementsWithErrors',
    'PassportRequiredElement',
    'PassportSuitableElement',
    'PasswordState',
    'PaymentForm',
    'PaymentReceipt',
    'PaymentResult',
    'PaymentsProviderStripe',
    'PersonalDetails',
    'PersonalDocument',
    'PhoneNumberAuthenticationSettings',
    'PhoneNumberInfo',
    'Photo',
    'PhotoSize',
    'PinChatMessage',
    'PingProxy',
    'Point',
    'Poll',
    'PollOption',
    'PollType',
    'PollTypeQuiz',
    'PollTypeRegular',
    'ProcessPushNotification',
    'ProfilePhoto',
    'Proxies',
    'Proxy',
    'ProxyType',
    'ProxyTypeHttp',
    'ProxyTypeMtproto',
    'ProxyTypeSocks5',
    'PublicChatType',
    'PublicChatTypeHasUsername',
    'PublicChatTypeIsLocationBased',
    'PushMessageContent',
    'PushMessageContentAnimation',
    'PushMessageContentAudio',
    'PushMessageContentBasicGroupChatCreate',
    'PushMessageContentChatAddMembers',
    'PushMessageContentChatChangePhoto',
    'PushMessageContentChatChangeTitle',
    'PushMessageContentChatDeleteMember',
    'PushMessageContentChatJoinByLink',
    'PushMessageContentContact',
    'PushMessageContentContactRegistered',
    'PushMessageContentDocument',
    'PushMessageContentGame',
    'PushMessageContentGameScore',
    'PushMessageContentHidden',
    'PushMessageContentInvoice',
    'PushMessageContentLocation',
    'PushMessageContentMediaAlbum',
    'PushMessageContentMessageForwards',
    'PushMessageContentPhoto',
    'PushMessageContentPoll',
    'PushMessageContentScreenshotTaken',
    'PushMessageContentSticker',
    'PushMessageContentText',
    'PushMessageContentVideo',
    'PushMessageContentVideoNote',
    'PushMessageContentVoiceNote',
    'PushReceiverId',
    'ReadAllChatMentions',
    'ReadFilePart',
    'RecommendedChatFilter',
    'RecommendedChatFilters',
    'RecoverAuthenticationPassword',
    'RecoverPassword',
    'RecoveryEmailAddress',
    'RegisterDevice',
    'RegisterUser',
    'RemoteFile',
    'RemoveBackground',
    'RemoveChatActionBar',
    'RemoveContacts',
    'RemoveFavoriteSticker',
    'RemoveNotification',
    'RemoveNotificationGroup',
    'RemoveProxy',
    'RemoveRecentHashtag',
    'RemoveRecentSticker',
    'RemoveRecentlyFoundChat',
    'RemoveSavedAnimation',
    'RemoveStickerFromSet',
    'RemoveTopChat',
    'ReorderChatFilters',
    'ReorderInstalledStickerSets',
    'ReplacePrimaryChatInviteLink',
    'ReplyMarkup',
    'ReplyMarkupForceReply',
    'ReplyMarkupInlineKeyboard',
    'ReplyMarkupRemoveKeyboard',
    'ReplyMarkupShowKeyboard',
    'ReportChat',
    'ReportChatPhoto',
    'ReportSupergroupSpam',
    'RequestAuthenticationPasswordRecovery',
    'RequestPasswordRecovery',
    'RequestQrCodeAuthentication',
    'ResendAuthenticationCode',
    'ResendChangePhoneNumberCode',
    'ResendEmailAddressVerificationCode',
    'ResendMessages',
    'ResendPhoneNumberConfirmationCode',
    'ResendPhoneNumberVerificationCode',
    'ResendRecoveryEmailAddressCode',
    'ResetAllNotificationSettings',
    'ResetBackgrounds',
    'ResetNetworkStatistics',
    'RevokeChatInviteLink',
    'RevokeGroupCallInviteLink',
    'RichText',
    'RichTextAnchor',
    'RichTextAnchorLink',
    'RichTextBold',
    'RichTextEmailAddress',
    'RichTextFixed',
    'RichTextIcon',
    'RichTextItalic',
    'RichTextMarked',
    'RichTextPhoneNumber',
    'RichTextPlain',
    'RichTextReference',
    'RichTextStrikethrough',
    'RichTextSubscript',
    'RichTextSuperscript',
    'RichTextUnderline',
    'RichTextUrl',
    'RichTexts',
    'SaveApplicationLogEvent',
    'SavedCredentials',
    'ScopeNotificationSettings',
    'SearchBackground',
    'SearchCallMessages',
    'SearchChatMembers',
    'SearchChatMessages',
    'SearchChatRecentLocationMessages',
    'SearchChats',
    'SearchChatsNearby',
    'SearchChatsOnServer',
    'SearchContacts',
    'SearchEmojis',
    'SearchHashtags',
    'SearchInstalledStickerSets',
    'SearchMessages',
    'SearchMessagesFilter',
    'SearchMessagesFilterAnimation',
    'SearchMessagesFilterAudio',
    'SearchMessagesFilterCall',
    'SearchMessagesFilterChatPhoto',
    'SearchMessagesFilterDocument',
    'SearchMessagesFilterEmpty',
    'SearchMessagesFilterFailedToSend',
    'SearchMessagesFilterMention',
    'SearchMessagesFilterMissedCall',
    'SearchMessagesFilterPhoto',
    'SearchMessagesFilterPhotoAndVideo',
    'SearchMessagesFilterPinned',
    'SearchMessagesFilterUnreadMention',
    'SearchMessagesFilterUrl',
    'SearchMessagesFilterVideo',
    'SearchMessagesFilterVideoNote',
    'SearchMessagesFilterVoiceAndVideoNote',
    'SearchMessagesFilterVoiceNote',
    'SearchPublicChat',
    'SearchPublicChats',
    'SearchSecretMessages',
    'SearchStickerSet',
    'SearchStickerSets',
    'SearchStickers',
    'Seconds',
    'SecretChat',
    'SecretChatState',
    'SecretChatStateClosed',
    'SecretChatStatePending',
    'SecretChatStateReady',
    'SendBotStartMessage',
    'SendCallDebugInformation',
    'SendCallRating',
    'SendCallSignalingData',
    'SendChatAction',
    'SendChatScreenshotTakenNotification',
    'SendCustomRequest',
    'SendEmailAddressVerificationCode',
    'SendInlineQueryResultMessage',
    'SendMessage',
    'SendMessageAlbum',
    'SendPassportAuthorizationForm',
    'SendPaymentForm',
    'SendPhoneNumberConfirmationCode',
    'SendPhoneNumberVerificationCode',
    'Session',
    'Sessions',
    'SetAccountTtl',
    'SetAlarm',
    'SetAuthenticationPhoneNumber',
    'SetAutoDownloadSettings',
    'SetBackground',
    'SetBio',
    'SetBotUpdatesStatus',
    'SetChatClientData',
    'SetChatDescription',
    'SetChatDiscussionGroup',
    'SetChatDraftMessage',
    'SetChatLocation',
    'SetChatMemberStatus',
    'SetChatMessageTtlSetting',
    'SetChatNotificationSettings',
    'SetChatPermissions',
    'SetChatPhoto',
    'SetChatSlowModeDelay',
    'SetChatTitle',
    'SetCommands',
    'SetCustomLanguagePack',
    'SetCustomLanguagePackString',
    'SetDatabaseEncryptionKey',
    'SetFileGenerationProgress',
    'SetGameScore',
    'SetGroupCallParticipantIsSpeaking',
    'SetGroupCallParticipantVolumeLevel',
    'SetGroupCallTitle',
    'SetInlineGameScore',
    'SetLocation',
    'SetLogStream',
    'SetLogTagVerbosityLevel',
    'SetLogVerbosityLevel',
    'SetName',
    'SetNetworkType',
    'SetOption',
    'SetPassportElement',
    'SetPassportElementErrors',
    'SetPassword',
    'SetPinnedChats',
    'SetPollAnswer',
    'SetProfilePhoto',
    'SetRecoveryEmailAddress',
    'SetScopeNotificationSettings',
    'SetStickerPositionInSet',
    'SetStickerSetThumbnail',
    'SetSupergroupStickerSet',
    'SetSupergroupUsername',
    'SetTdlibParameters',
    'SetUserPrivacySettingRules',
    'SetUsername',
    'SharePhoneNumber',
    'ShippingOption',
    'StartGroupCallRecording',
    'StatisticalGraph',
    'StatisticalGraphAsync',
    'StatisticalGraphData',
    'StatisticalGraphError',
    'StatisticalValue',
    'Sticker',
    'StickerSet',
    'StickerSetInfo',
    'StickerSets',
    'Stickers',
    'StopPoll',
    'StorageStatistics',
    'StorageStatisticsByChat',
    'StorageStatisticsByFileType',
    'StorageStatisticsFast',
    'SuggestedAction',
    'SuggestedActionCheckPhoneNumber',
    'SuggestedActionConvertToBroadcastGroup',
    'SuggestedActionEnableArchiveAndMuteNewChats',
    'SuggestedActionSeeTicksHint',
    'Supergroup',
    'SupergroupFullInfo',
    'SupergroupMembersFilter',
    'SupergroupMembersFilterAdministrators',
    'SupergroupMembersFilterBanned',
    'SupergroupMembersFilterBots',
    'SupergroupMembersFilterContacts',
    'SupergroupMembersFilterMention',
    'SupergroupMembersFilterRecent',
    'SupergroupMembersFilterRestricted',
    'SupergroupMembersFilterSearch',
    'SynchronizeLanguagePack',
    'TMeUrl',
    'TMeUrlType',
    'TMeUrlTypeChatInvite',
    'TMeUrlTypeStickerSet',
    'TMeUrlTypeSupergroup',
    'TMeUrlTypeUser',
    'TMeUrls',
    'TdlibParameters',
    'TemporaryPasswordState',
    'TerminateAllOtherSessions',
    'TerminateSession',
    'TermsOfService',
    'TestBytes',
    'TestCallBytes',
    'TestCallEmpty',
    'TestCallString',
    'TestCallVectorInt',
    'TestCallVectorIntObject',
    'TestCallVectorString',
    'TestCallVectorStringObject',
    'TestGetDifference',
    'TestInt',
    'TestNetwork',
    'TestProxy',
    'TestReturnError',
    'TestSquareInt',
    'TestString',
    'TestUseUpdate',
    'TestVectorInt',
    'TestVectorIntObject',
    'TestVectorString',
    'TestVectorStringObject',
    'Text',
    'TextEntities',
    'TextEntity',
    'TextEntityType',
    'TextEntityTypeBankCardNumber',
    'TextEntityTypeBold',
    'TextEntityTypeBotCommand',
    'TextEntityTypeCashtag',
    'TextEntityTypeCode',
    'TextEntityTypeEmailAddress',
    'TextEntityTypeHashtag',
    'TextEntityTypeItalic',
    'TextEntityTypeMention',
    'TextEntityTypeMentionName',
    'TextEntityTypePhoneNumber',
    'TextEntityTypePre',
    'TextEntityTypePreCode',
    'TextEntityTypeStrikethrough',
    'TextEntityTypeTextUrl',
    'TextEntityTypeUnderline',
    'TextEntityTypeUrl',
    'TextParseMode',
    'TextParseModeHTML',
    'TextParseModeMarkdown',
    'Thumbnail',
    'ThumbnailFormat',
    'ThumbnailFormatGif',
    'ThumbnailFormatJpeg',
    'ThumbnailFormatMpeg4',
    'ThumbnailFormatPng',
    'ThumbnailFormatTgs',
    'ThumbnailFormatWebp',
    'ToggleChatDefaultDisableNotification',
    'ToggleChatIsMarkedAsUnread',
    'ToggleChatIsPinned',
    'ToggleGroupCallMuteNewParticipants',
    'ToggleGroupCallParticipantIsHandRaised',
    'ToggleGroupCallParticipantIsMuted',
    'ToggleMessageSenderIsBlocked',
    'ToggleSupergroupIsAllHistoryAvailable',
    'ToggleSupergroupIsBroadcastGroup',
    'ToggleSupergroupSignMessages',
    'TopChatCategory',
    'TopChatCategoryBots',
    'TopChatCategoryCalls',
    'TopChatCategoryChannels',
    'TopChatCategoryForwardChats',
    'TopChatCategoryGroups',
    'TopChatCategoryInlineBots',
    'TopChatCategoryUsers',
    'TransferChatOwnership',
    'UnpinAllChatMessages',
    'UnpinChatMessage',
    'Update',
    'UpdateActiveNotifications',
    'UpdateAnimationSearchParameters',
    'UpdateAuthorizationState',
    'UpdateBasicGroup',
    'UpdateBasicGroupFullInfo',
    'UpdateCall',
    'UpdateChatActionBar',
    'UpdateChatDefaultDisableNotification',
    'UpdateChatDraftMessage',
    'UpdateChatFilters',
    'UpdateChatHasScheduledMessages',
    'UpdateChatIsBlocked',
    'UpdateChatIsMarkedAsUnread',
    'UpdateChatLastMessage',
    'UpdateChatMember',
    'UpdateChatMessageTtlSetting',
    'UpdateChatNotificationSettings',
    'UpdateChatOnlineMemberCount',
    'UpdateChatPermissions',
    'UpdateChatPhoto',
    'UpdateChatPosition',
    'UpdateChatReadInbox',
    'UpdateChatReadOutbox',
    'UpdateChatReplyMarkup',
    'UpdateChatTitle',
    'UpdateChatUnreadMentionCount',
    'UpdateChatVoiceChat',
    'UpdateConnectionState',
    'UpdateDeleteMessages',
    'UpdateDiceEmojis',
    'UpdateFavoriteStickers',
    'UpdateFile',
    'UpdateFileGenerationStart',
    'UpdateFileGenerationStop',
    'UpdateGroupCall',
    'UpdateGroupCallParticipant',
    'UpdateHavePendingNotifications',
    'UpdateInstalledStickerSets',
    'UpdateLanguagePackStrings',
    'UpdateMessageContent',
    'UpdateMessageContentOpened',
    'UpdateMessageEdited',
    'UpdateMessageInteractionInfo',
    'UpdateMessageIsPinned',
    'UpdateMessageLiveLocationViewed',
    'UpdateMessageMentionRead',
    'UpdateMessageSendAcknowledged',
    'UpdateMessageSendFailed',
    'UpdateMessageSendSucceeded',
    'UpdateNewCallSignalingData',
    'UpdateNewCallbackQuery',
    'UpdateNewChat',
    'UpdateNewChosenInlineResult',
    'UpdateNewCustomEvent',
    'UpdateNewCustomQuery',
    'UpdateNewInlineCallbackQuery',
    'UpdateNewInlineQuery',
    'UpdateNewMessage',
    'UpdateNewPreCheckoutQuery',
    'UpdateNewShippingQuery',
    'UpdateNotification',
    'UpdateNotificationGroup',
    'UpdateOption',
    'UpdatePoll',
    'UpdatePollAnswer',
    'UpdateRecentStickers',
    'UpdateSavedAnimations',
    'UpdateScopeNotificationSettings',
    'UpdateSecretChat',
    'UpdateSelectedBackground',
    'UpdateServiceNotification',
    'UpdateStickerSet',
    'UpdateSuggestedActions',
    'UpdateSupergroup',
    'UpdateSupergroupFullInfo',
    'UpdateTermsOfService',
    'UpdateTrendingStickerSets',
    'UpdateUnreadChatCount',
    'UpdateUnreadMessageCount',
    'UpdateUser',
    'UpdateUserChatAction',
    'UpdateUserFullInfo',
    'UpdateUserPrivacySettingRules',
    'UpdateUserStatus',
    'UpdateUsersNearby',
    'Updates',
    'UpgradeBasicGroupChatToSupergroupChat',
    'UploadFile',
    'UploadStickerFile',
    'User',
    'UserFullInfo',
    'UserPrivacySetting',
    'UserPrivacySettingAllowCalls',
    'UserPrivacySettingAllowChatInvites',
    'UserPrivacySettingAllowFindingByPhoneNumber',
    'UserPrivacySettingAllowPeerToPeerCalls',
    'UserPrivacySettingShowLinkInForwardedMessages',
    'UserPrivacySettingShowPhoneNumber',
    'UserPrivacySettingShowProfilePhoto',
    'UserPrivacySettingShowStatus',
    'UserPrivacySettingRule',
    'UserPrivacySettingRuleAllowAll',
    'UserPrivacySettingRuleAllowChatMembers',
    'UserPrivacySettingRuleAllowContacts',
    'UserPrivacySettingRuleAllowUsers',
    'UserPrivacySettingRuleRestrictAll',
    'UserPrivacySettingRuleRestrictChatMembers',
    'UserPrivacySettingRuleRestrictContacts',
    'UserPrivacySettingRuleRestrictUsers',
    'UserPrivacySettingRules',
    'UserStatus',
    'UserStatusEmpty',
    'UserStatusLastMonth',
    'UserStatusLastWeek',
    'UserStatusOffline',
    'UserStatusOnline',
    'UserStatusRecently',
    'UserType',
    'UserTypeBot',
    'UserTypeDeleted',
    'UserTypeRegular',
    'UserTypeUnknown',
    'Users',
    'ValidateOrderInfo',
    'ValidatedOrderInfo',
    'VectorPathCommand',
    'VectorPathCommandCubicBezierCurve',
    'VectorPathCommandLine',
    'Venue',
    'Video',
    'VideoNote',
    'ViewMessages',
    'ViewTrendingStickerSets',
    'VoiceChat',
    'VoiceNote',
    'WebPage',
    'WebPageInstantView',
    'WriteGeneratedFilePart',
]
